# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/satellite.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/satellite.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import satellite_pb2 as admin_dot_v1_dot_types_dot_v1_dot_satellite__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/satellite.proto\x12\x08\x61\x64min.v1\x1a!admin/v1/types/v1/satellite.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"c\n\x16\x43reateSatelliteRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x35\n\x16termination_protection\x18\x02 \x01(\x08R\x15terminationProtection\")\n\x17\x43reateSatelliteResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\")\n\x17GetSatelliteByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"V\n\x18GetSatelliteByIdResponse\x12:\n\tsatellite\x18\x01 \x01(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\tsatellite\"\x16\n\x14GetSatellitesRequest\"U\n\x15GetSatellitesResponse\x12<\n\nsatellites\x18\x01 \x03(\x0b\x32\x1c.admin.v1.types.v1.SatelliteR\nsatellites\"+\n\x19GetSatelliteApiKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"5\n\x1aGetSatelliteApiKeyResponse\x12\x17\n\x07\x61pi_key\x18\x01 \x01(\tR\x06\x61piKey\"s\n\x16UpdateSatelliteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x35\n\x16termination_protection\x18\x03 \x01(\x08R\x15terminationProtection\"\x19\n\x17UpdateSatelliteResponse\"(\n\x16\x44\x65leteSatelliteRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteSatelliteResponse\"\xc8\x01\n\x17SatelliteOnlineInstance\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12\x37\n\tlast_seen\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastSeen\x12\x39\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\"8\n&GetOnlineInstancesBySatelliteIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"j\n\'GetOnlineInstancesBySatelliteIdResponse\x12?\n\tinstances\x18\x01 \x03(\x0b\x32!.admin.v1.SatelliteOnlineInstanceR\tinstances2\xb3\x05\n\x10SatelliteService\x12V\n\x0f\x43reateSatellite\x12 .admin.v1.CreateSatelliteRequest\x1a!.admin.v1.CreateSatelliteResponse\x12Y\n\x10GetSatelliteById\x12!.admin.v1.GetSatelliteByIdRequest\x1a\".admin.v1.GetSatelliteByIdResponse\x12P\n\rGetSatellites\x12\x1e.admin.v1.GetSatellitesRequest\x1a\x1f.admin.v1.GetSatellitesResponse\x12_\n\x12GetSatelliteApiKey\x12#.admin.v1.GetSatelliteApiKeyRequest\x1a$.admin.v1.GetSatelliteApiKeyResponse\x12\x88\x01\n\x1fGetOnlineInstancesBySatelliteId\x12\x30.admin.v1.GetOnlineInstancesBySatelliteIdRequest\x1a\x31.admin.v1.GetOnlineInstancesBySatelliteIdResponse\"\x00\x12V\n\x0fUpdateSatellite\x12 .admin.v1.UpdateSatelliteRequest\x1a!.admin.v1.UpdateSatelliteResponse\x12V\n\x0f\x44\x65leteSatellite\x12 .admin.v1.DeleteSatelliteRequest\x1a!.admin.v1.DeleteSatelliteResponseB\xa4\x01\n\x0c\x63om.admin.v1B\x0eSatelliteProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.satellite_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\016SatelliteProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATESATELLITEREQUEST']._serialized_start=106
  _globals['_CREATESATELLITEREQUEST']._serialized_end=205
  _globals['_CREATESATELLITERESPONSE']._serialized_start=207
  _globals['_CREATESATELLITERESPONSE']._serialized_end=248
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_start=250
  _globals['_GETSATELLITEBYIDREQUEST']._serialized_end=291
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_start=293
  _globals['_GETSATELLITEBYIDRESPONSE']._serialized_end=379
  _globals['_GETSATELLITESREQUEST']._serialized_start=381
  _globals['_GETSATELLITESREQUEST']._serialized_end=403
  _globals['_GETSATELLITESRESPONSE']._serialized_start=405
  _globals['_GETSATELLITESRESPONSE']._serialized_end=490
  _globals['_GETSATELLITEAPIKEYREQUEST']._serialized_start=492
  _globals['_GETSATELLITEAPIKEYREQUEST']._serialized_end=535
  _globals['_GETSATELLITEAPIKEYRESPONSE']._serialized_start=537
  _globals['_GETSATELLITEAPIKEYRESPONSE']._serialized_end=590
  _globals['_UPDATESATELLITEREQUEST']._serialized_start=592
  _globals['_UPDATESATELLITEREQUEST']._serialized_end=707
  _globals['_UPDATESATELLITERESPONSE']._serialized_start=709
  _globals['_UPDATESATELLITERESPONSE']._serialized_end=734
  _globals['_DELETESATELLITEREQUEST']._serialized_start=736
  _globals['_DELETESATELLITEREQUEST']._serialized_end=776
  _globals['_DELETESATELLITERESPONSE']._serialized_start=778
  _globals['_DELETESATELLITERESPONSE']._serialized_end=803
  _globals['_SATELLITEONLINEINSTANCE']._serialized_start=806
  _globals['_SATELLITEONLINEINSTANCE']._serialized_end=1006
  _globals['_GETONLINEINSTANCESBYSATELLITEIDREQUEST']._serialized_start=1008
  _globals['_GETONLINEINSTANCESBYSATELLITEIDREQUEST']._serialized_end=1064
  _globals['_GETONLINEINSTANCESBYSATELLITEIDRESPONSE']._serialized_start=1066
  _globals['_GETONLINEINSTANCESBYSATELLITEIDRESPONSE']._serialized_end=1172
  _globals['_SATELLITESERVICE']._serialized_start=1175
  _globals['_SATELLITESERVICE']._serialized_end=1866
# @@protoc_insertion_point(module_scope)
