# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_cloud_pb2 as admin_dot_v1_dot_integration__cloud__pb2


class CloudServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDataplaneById = channel.unary_unary(
                '/admin.v1.CloudService/GetDataplaneById',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdResponse.FromString,
                _registered_method=True)
        self.GetDataplaneRoutesById = channel.unary_unary(
                '/admin.v1.CloudService/GetDataplaneRoutesById',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdResponse.FromString,
                _registered_method=True)
        self.GetDataplaneStacksByCloudAccountId = channel.unary_unary(
                '/admin.v1.CloudService/GetDataplaneStacksByCloudAccountId',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdResponse.FromString,
                _registered_method=True)
        self.CreateAwsConnectionSession = channel.unary_unary(
                '/admin.v1.CloudService/CreateAwsConnectionSession',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionResponse.FromString,
                _registered_method=True)
        self.DeleteAwsConnectionSession = channel.unary_unary(
                '/admin.v1.CloudService/DeleteAwsConnectionSession',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionResponse.FromString,
                _registered_method=True)
        self.GetIntegrationsCloudAccountById = channel.unary_unary(
                '/admin.v1.CloudService/GetIntegrationsCloudAccountById',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdResponse.FromString,
                _registered_method=True)
        self.GetIntegrationsCloudAccounts = channel.unary_unary(
                '/admin.v1.CloudService/GetIntegrationsCloudAccounts',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsResponse.FromString,
                _registered_method=True)
        self.CreateGcpConnectionSession = channel.unary_unary(
                '/admin.v1.CloudService/CreateGcpConnectionSession',
                request_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionResponse.FromString,
                _registered_method=True)


class CloudServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetDataplaneById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataplaneRoutesById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataplaneStacksByCloudAccountId(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAwsConnectionSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAwsConnectionSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationsCloudAccountById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationsCloudAccounts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateGcpConnectionSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetDataplaneById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataplaneById,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdResponse.SerializeToString,
            ),
            'GetDataplaneRoutesById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataplaneRoutesById,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdResponse.SerializeToString,
            ),
            'GetDataplaneStacksByCloudAccountId': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataplaneStacksByCloudAccountId,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdResponse.SerializeToString,
            ),
            'CreateAwsConnectionSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAwsConnectionSession,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionResponse.SerializeToString,
            ),
            'DeleteAwsConnectionSession': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAwsConnectionSession,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionResponse.SerializeToString,
            ),
            'GetIntegrationsCloudAccountById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationsCloudAccountById,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdResponse.SerializeToString,
            ),
            'GetIntegrationsCloudAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationsCloudAccounts,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsResponse.SerializeToString,
            ),
            'CreateGcpConnectionSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGcpConnectionSession,
                    request_deserializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.CloudService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.CloudService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CloudService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetDataplaneById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetDataplaneById',
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataplaneRoutesById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetDataplaneRoutesById',
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneRoutesByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDataplaneStacksByCloudAccountId(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetDataplaneStacksByCloudAccountId',
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetDataplaneStacksByCloudAccountIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateAwsConnectionSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/CreateAwsConnectionSession',
            admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.CreateAwsConnectionSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteAwsConnectionSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/DeleteAwsConnectionSession',
            admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.DeleteAwsConnectionSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationsCloudAccountById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetIntegrationsCloudAccountById',
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationsCloudAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/GetIntegrationsCloudAccounts',
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.GetIntegrationsCloudAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateGcpConnectionSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CloudService/CreateGcpConnectionSession',
            admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionRequest.SerializeToString,
            admin_dot_v1_dot_integration__cloud__pb2.CreateGcpConnectionSessionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
