# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/etl.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/etl.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x64min/v1/types/v1/etl.proto\x12\x11\x61\x64min.v1.types.v1\"f\n\x08\x45TLGroup\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\"\xc5\x02\n\x0c\x45TLConnector\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12%\n\x0e\x64\x65stination_id\x18\x04 \x01(\tR\rdestinationId\x12\x19\n\x08group_id\x18\x05 \x01(\tR\x07groupId\x12%\n\x0e\x63onnector_type\x18\x06 \x01(\tR\rconnectorType\x12!\n\x0cservice_name\x18\x07 \x01(\tR\x0bserviceName\x12\x1b\n\thost_name\x18\x08 \x01(\tR\x08hostName\x12#\n\rdatabase_name\x18\t \x01(\tR\x0c\x64\x61tabaseName\x12\x1f\n\x0blast_synced\x18\n \x01(\x05R\nlastSynced\"\xa4\x02\n\x0e\x45TLDestination\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12\x19\n\x08group_id\x18\x04 \x01(\tR\x07groupId\x12)\n\x10\x64\x65stination_type\x18\x05 \x01(\tR\x0f\x64\x65stinationType\x12!\n\x0cservice_name\x18\x06 \x01(\tR\x0bserviceName\x12\x1b\n\thost_name\x18\x07 \x01(\tR\x08hostName\x12#\n\rdatabase_name\x18\x08 \x01(\tR\x0c\x64\x61tabaseName\x12\x1f\n\x0blast_synced\x18\t \x01(\x05R\nlastSynced\"\x9b\x02\n\x10\x45TLSchemaLineage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12!\n\x0c\x63onnector_id\x18\x04 \x01(\tR\x0b\x63onnectorId\x12%\n\x0e\x64\x65stination_id\x18\x05 \x01(\tR\rdestinationId\x12#\n\rsource_schema\x18\x06 \x01(\tR\x0csourceSchema\x12-\n\x12\x64\x65stination_schema\x18\x07 \x01(\tR\x11\x64\x65stinationSchema\x12!\n\x0clast_updated\x18\x08 \x01(\x05R\x0blastUpdated\"\xb3\x02\n\x0f\x45TLTableLineage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12!\n\x0c\x63onnector_id\x18\x04 \x01(\tR\x0b\x63onnectorId\x12%\n\x0e\x64\x65stination_id\x18\x05 \x01(\tR\rdestinationId\x12\x1b\n\tschema_id\x18\x06 \x01(\tR\x08schemaId\x12!\n\x0csource_table\x18\x07 \x01(\tR\x0bsourceTable\x12+\n\x11\x64\x65stination_table\x18\x08 \x01(\tR\x10\x64\x65stinationTable\x12!\n\x0clast_updated\x18\t \x01(\x05R\x0blastUpdated\"\xda\x03\n\x10\x45TLColumnLineage\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12\x1f\n\x0bplatform_id\x18\x03 \x01(\tR\nplatformId\x12!\n\x0c\x63onnector_id\x18\x04 \x01(\tR\x0b\x63onnectorId\x12%\n\x0e\x64\x65stination_id\x18\x05 \x01(\tR\rdestinationId\x12\x1b\n\tschema_id\x18\x06 \x01(\tR\x08schemaId\x12\x19\n\x08table_id\x18\x07 \x01(\tR\x07tableId\x12#\n\rsource_column\x18\x08 \x01(\tR\x0csourceColumn\x12-\n\x12\x64\x65stination_column\x18\t \x01(\tR\x11\x64\x65stinationColumn\x12(\n\x10source_data_type\x18\n \x01(\tR\x0esourceDataType\x12\x32\n\x15\x64\x65stination_data_type\x18\x0b \x01(\tR\x13\x64\x65stinationDataType\x12$\n\x0eis_primary_key\x18\x0c \x01(\x08R\x0cisPrimaryKey\x12$\n\x0eis_foreign_key\x18\r \x01(\x08R\x0cisForeignKey\"\xd0\x01\n\nETLMapping\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x15\n\x06org_id\x18\x02 \x01(\tR\x05orgId\x12!\n\x0c\x63onnector_id\x18\x03 \x01(\tR\x0b\x63onnectorId\x12\x32\n\x15platform_connector_id\x18\x04 \x01(\tR\x13platformConnectorId\x12#\n\rplatform_type\x18\x05 \x01(\tR\x0cplatformType\x12\x1f\n\x0blast_synced\x18\x06 \x01(\x05R\nlastSyncedB\xd6\x01\n\x15\x63om.admin.v1.types.v1B\x08\x45tlProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.etl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\010EtlProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_ETLGROUP']._serialized_start=50
  _globals['_ETLGROUP']._serialized_end=152
  _globals['_ETLCONNECTOR']._serialized_start=155
  _globals['_ETLCONNECTOR']._serialized_end=480
  _globals['_ETLDESTINATION']._serialized_start=483
  _globals['_ETLDESTINATION']._serialized_end=775
  _globals['_ETLSCHEMALINEAGE']._serialized_start=778
  _globals['_ETLSCHEMALINEAGE']._serialized_end=1061
  _globals['_ETLTABLELINEAGE']._serialized_start=1064
  _globals['_ETLTABLELINEAGE']._serialized_end=1371
  _globals['_ETLCOLUMNLINEAGE']._serialized_start=1374
  _globals['_ETLCOLUMNLINEAGE']._serialized_end=1848
  _globals['_ETLMAPPING']._serialized_start=1851
  _globals['_ETLMAPPING']._serialized_end=2059
# @@protoc_insertion_point(module_scope)
