# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/audit.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/audit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import log_pb2 as admin_dot_v1_dot_types_dot_v1_dot_log__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61\x64min/v1/audit.proto\x12\x08\x61\x64min.v1\x1a\x1b\x61\x64min/v1/types/v1/log.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"f\n\x0eGetLogsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06offset\x18\x02 \x01(\x05R\x06offset\x12\x1b\n\x06\x66ilter\x18\x03 \x01(\tH\x00R\x06\x66ilter\x88\x01\x01\x42\t\n\x07_filter\"#\n\x11GetLogByIDRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x0fGetLogsResponse\x12\x30\n\x04logs\x18\x01 \x03(\x0b\x32\x1c.admin.v1.types.v1.FormalLogR\x04logs\x12\x19\n\x08has_more\x18\x02 \x01(\x08R\x07hasMore\"D\n\x12GetLogByIDResponse\x12.\n\x03log\x18\x01 \x01(\x0b\x32\x1c.admin.v1.types.v1.FormalLogR\x03log\"*\n\x18GetEventBySessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"O\n\x19GetEventBySessionResponse\x12\x32\n\nevent_data\x18\x01 \x03(\x0b\x32\x13.admin.v1.EventDataR\teventData\"\xa6\x01\n\tEventData\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x1d\n\nsession_id\x18\x03 \x01(\tR\tsessionId\x12\x14\n\x05\x62ytes\x18\x04 \x01(\x05R\x05\x62ytes\x12\x16\n\x06offset\x18\x05 \x01(\x05R\x06offset\")\n\x17GetDataBySessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"z\n\x07SshData\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0cR\x04\x64\x61ta\x12!\n\x0cmessage_type\x18\x03 \x01(\tR\x0bmessageType\"H\n\x18GetDataBySessionResponse\x12,\n\x08ssh_data\x18\x01 \x03(\x0b\x32\x11.admin.v1.SshDataR\x07sshData2\xdc\x02\n\x10\x41uditLogsService\x12@\n\x07GetLogs\x12\x18.admin.v1.GetLogsRequest\x1a\x19.admin.v1.GetLogsResponse\"\x00\x12I\n\nGetLogByID\x12\x1b.admin.v1.GetLogByIDRequest\x1a\x1c.admin.v1.GetLogByIDResponse\"\x00\x12^\n\x11GetEventBySession\x12\".admin.v1.GetEventBySessionRequest\x1a#.admin.v1.GetEventBySessionResponse\"\x00\x12[\n\x10GetDataBySession\x12!.admin.v1.GetDataBySessionRequest\x1a\".admin.v1.GetDataBySessionResponse\"\x00\x42\xa0\x01\n\x0c\x63om.admin.v1B\nAuditProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.audit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\nAuditProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETLOGSREQUEST']._serialized_start=96
  _globals['_GETLOGSREQUEST']._serialized_end=198
  _globals['_GETLOGBYIDREQUEST']._serialized_start=200
  _globals['_GETLOGBYIDREQUEST']._serialized_end=235
  _globals['_GETLOGSRESPONSE']._serialized_start=237
  _globals['_GETLOGSRESPONSE']._serialized_end=331
  _globals['_GETLOGBYIDRESPONSE']._serialized_start=333
  _globals['_GETLOGBYIDRESPONSE']._serialized_end=401
  _globals['_GETEVENTBYSESSIONREQUEST']._serialized_start=403
  _globals['_GETEVENTBYSESSIONREQUEST']._serialized_end=445
  _globals['_GETEVENTBYSESSIONRESPONSE']._serialized_start=447
  _globals['_GETEVENTBYSESSIONRESPONSE']._serialized_end=526
  _globals['_EVENTDATA']._serialized_start=529
  _globals['_EVENTDATA']._serialized_end=695
  _globals['_GETDATABYSESSIONREQUEST']._serialized_start=697
  _globals['_GETDATABYSESSIONREQUEST']._serialized_end=738
  _globals['_SSHDATA']._serialized_start=740
  _globals['_SSHDATA']._serialized_end=862
  _globals['_GETDATABYSESSIONRESPONSE']._serialized_start=864
  _globals['_GETDATABYSESSIONRESPONSE']._serialized_end=936
  _globals['_AUDITLOGSSERVICE']._serialized_start=939
  _globals['_AUDITLOGSSERVICE']._serialized_end=1287
# @@protoc_insertion_point(module_scope)
