# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_mfa.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_mfa.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_mfa.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"l\n\x1aListIntegrationMfasRequest\x12 \n\x05limit\x18\x01 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xf4\x03 \x00R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"\xa1\x01\n\x1bListIntegrationMfasResponse\x12<\n\x0cintegrations\x18\x01 \x03(\x0b\x32\x18.admin.v1.IntegrationMfaR\x0cintegrations\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"7\n\x1cGetIntegrationMfaByIdRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"[\n\x1dGetIntegrationMfaByIdResponse\x12:\n\x0bintegration\x18\x01 \x01(\x0b\x32\x18.admin.v1.IntegrationMfaR\x0bintegration\"\xf4\x01\n\x1b\x43reateIntegrationMfaRequest\x12\x1e\n\x04type\x18\x01 \x01(\tB\n\xfa\x42\x07r\x05R\x03\x64uoR\x04type\x12.\n\x13\x64uo_integration_key\x18\x02 \x01(\tR\x11\x64uoIntegrationKey\x12$\n\x0e\x64uo_secret_key\x18\x03 \x01(\tR\x0c\x64uoSecretKey\x12(\n\x10\x64uo_api_hostname\x18\x04 \x01(\tR\x0e\x64uoApiHostname\x12\x35\n\x16termination_protection\x18\x05 \x01(\x08R\x15terminationProtection\".\n\x1c\x43reateIntegrationMfaResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"6\n\x1b\x44\x65leteIntegrationMfaRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x1e\n\x1c\x44\x65leteIntegrationMfaResponse\"m\n\x1bUpdateIntegrationMfaRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x35\n\x16termination_protection\x18\x02 \x01(\x08R\x15terminationProtection\"\x1e\n\x1cUpdateIntegrationMfaResponse\"\xe1\x02\n\x0eIntegrationMfa\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x39\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x12\n\x04type\x18\x04 \x01(\tR\x04type\x12.\n\x13\x64uo_integration_key\x18\x05 \x01(\tR\x11\x64uoIntegrationKey\x12$\n\x0e\x64uo_secret_key\x18\x06 \x01(\tR\x0c\x64uoSecretKey\x12(\n\x10\x64uo_api_hostname\x18\x07 \x01(\tR\x0e\x64uoApiHostname\x12\x35\n\x16termination_protection\x18\x08 \x01(\x08R\x15terminationProtection2\xa4\x04\n\x15IntegrationMfaService\x12\x64\n\x13ListIntegrationMfas\x12$.admin.v1.ListIntegrationMfasRequest\x1a%.admin.v1.ListIntegrationMfasResponse\"\x00\x12j\n\x15GetIntegrationMfaById\x12&.admin.v1.GetIntegrationMfaByIdRequest\x1a\'.admin.v1.GetIntegrationMfaByIdResponse\"\x00\x12g\n\x14UpdateIntegrationMfa\x12%.admin.v1.UpdateIntegrationMfaRequest\x1a&.admin.v1.UpdateIntegrationMfaResponse\"\x00\x12g\n\x14\x43reateIntegrationMfa\x12%.admin.v1.CreateIntegrationMfaRequest\x1a&.admin.v1.CreateIntegrationMfaResponse\"\x00\x12g\n\x14\x44\x65leteIntegrationMfa\x12%.admin.v1.DeleteIntegrationMfaRequest\x1a&.admin.v1.DeleteIntegrationMfaResponse\"\x00\x42\xa9\x01\n\x0c\x63om.admin.v1B\x13IntegrationMfaProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_mfa_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationMfaProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTINTEGRATIONMFASREQUEST'].fields_by_name['limit']._loaded_options = None
  _globals['_LISTINTEGRATIONMFASREQUEST'].fields_by_name['limit']._serialized_options = b'\372B\007\032\005\030\364\003 \000'
  _globals['_GETINTEGRATIONMFABYIDREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETINTEGRATIONMFABYIDREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEINTEGRATIONMFAREQUEST'].fields_by_name['type']._loaded_options = None
  _globals['_CREATEINTEGRATIONMFAREQUEST'].fields_by_name['type']._serialized_options = b'\372B\007r\005R\003duo'
  _globals['_DELETEINTEGRATIONMFAREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEINTEGRATIONMFAREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEINTEGRATIONMFAREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEINTEGRATIONMFAREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_LISTINTEGRATIONMFASREQUEST']._serialized_start=144
  _globals['_LISTINTEGRATIONMFASREQUEST']._serialized_end=252
  _globals['_LISTINTEGRATIONMFASRESPONSE']._serialized_start=255
  _globals['_LISTINTEGRATIONMFASRESPONSE']._serialized_end=416
  _globals['_GETINTEGRATIONMFABYIDREQUEST']._serialized_start=418
  _globals['_GETINTEGRATIONMFABYIDREQUEST']._serialized_end=473
  _globals['_GETINTEGRATIONMFABYIDRESPONSE']._serialized_start=475
  _globals['_GETINTEGRATIONMFABYIDRESPONSE']._serialized_end=566
  _globals['_CREATEINTEGRATIONMFAREQUEST']._serialized_start=569
  _globals['_CREATEINTEGRATIONMFAREQUEST']._serialized_end=813
  _globals['_CREATEINTEGRATIONMFARESPONSE']._serialized_start=815
  _globals['_CREATEINTEGRATIONMFARESPONSE']._serialized_end=861
  _globals['_DELETEINTEGRATIONMFAREQUEST']._serialized_start=863
  _globals['_DELETEINTEGRATIONMFAREQUEST']._serialized_end=917
  _globals['_DELETEINTEGRATIONMFARESPONSE']._serialized_start=919
  _globals['_DELETEINTEGRATIONMFARESPONSE']._serialized_end=949
  _globals['_UPDATEINTEGRATIONMFAREQUEST']._serialized_start=951
  _globals['_UPDATEINTEGRATIONMFAREQUEST']._serialized_end=1060
  _globals['_UPDATEINTEGRATIONMFARESPONSE']._serialized_start=1062
  _globals['_UPDATEINTEGRATIONMFARESPONSE']._serialized_end=1092
  _globals['_INTEGRATIONMFA']._serialized_start=1095
  _globals['_INTEGRATIONMFA']._serialized_end=1448
  _globals['_INTEGRATIONMFASERVICE']._serialized_start=1451
  _globals['_INTEGRATIONMFASERVICE']._serialized_end=1999
# @@protoc_insertion_point(module_scope)
