# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/datastore.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/datastore.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61\x64min/v1/datastore.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"\x80\x03\n\x16\x43reateDatastoreRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1a\n\x08hostname\x18\x02 \x01(\tR\x08hostname\x12\x12\n\x04port\x18\x03 \x01(\x05R\x04port\x12\x1e\n\ntechnology\x18\x04 \x01(\tR\ntechnology\x12/\n\x14health_check_db_name\x18\x05 \x01(\tR\x11healthCheckDbName\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\x06 \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x07 \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\x12 \n\x0b\x65nvironment\x18\x08 \x01(\tR\x0b\x65nvironment\x12\x35\n\x16termination_protection\x18\t \x01(\x08R\x15terminationProtection\")\n\x17\x43reateDatastoreResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"%\n\x13GetDatastoreRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"I\n\x14GetDatastoreResponse\x12\x31\n\tdatastore\x18\x01 \x01(\x0b\x32\x13.admin.v1.DatastoreR\tdatastore\"\xea\x01\n\x14GetDatastoresRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\x12\x16\n\x06search\x18\x05 \x01(\tR\x06search\x12^\n\rsearch_fields\x18\x06 \x03(\tB9\xfa\x42\x36\x92\x01\x33\"1r/R\x04nameR\x08hostnameR\x04portR\ntechnologyR\x0b\x65nvironmentR\x0csearchFields\"\x92\x01\n\x15GetDatastoresResponse\x12\x33\n\ndatastores\x18\x01 \x03(\x0b\x32\x13.admin.v1.DatastoreR\ndatastores\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"(\n\x16\x44\x65leteDatastoreRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x19\n\x17\x44\x65leteDatastoreResponse\"@\n\x1aUpdateDatastoreNameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x1d\n\x1bUpdateDatastoreNameResponse\"\xaa\x01\n\x1eUpdateDbDiscoveryConfigRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\x02 \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x03 \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\"!\n\x1fUpdateDbDiscoveryConfigResponse\"j\n\'UpdateDataStoreHealthCheckDbNameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12/\n\x14health_check_db_name\x18\x02 \x01(\tR\x11healthCheckDbName\"*\n(UpdateDataStoreHealthCheckDbNameResponse\"u\n+UpdateDataStoreDefaultAccessBehaviorRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x36\n\x17\x64\x65\x66\x61ult_access_behavior\x18\x02 \x01(\tR\x15\x64\x65\x66\x61ultAccessBehavior\".\n,UpdateDataStoreDefaultAccessBehaviorResponse\"h\n\x1fSetTerminationProtectionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x35\n\x16termination_protection\x18\x02 \x01(\x08R\x15terminationProtection\"\"\n SetTerminationProtectionResponse\"*\n\x18GetLinkedSidecarsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"P\n\x19GetLinkedSidecarsResponse\x12\x33\n\x08sidecars\x18\x01 \x03(\x0b\x32\x17.admin.v1.LinkedSidecarR\x08sidecars\"h\n\rLinkedSidecar\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1a\n\x08hostname\x18\x03 \x01(\tR\x08hostname\x12\x17\n\x07link_id\x18\x04 \x01(\tR\x06linkId\"\xf1\x04\n\tDatastore\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04name\x18\x03 \x01(\tR\x04name\x12\x12\n\x04port\x18\x04 \x01(\x05R\x04port\x12\x1a\n\x08hostname\x18\x05 \x01(\tR\x08hostname\x12/\n\x14health_check_db_name\x18\x06 \x01(\tR\x11healthCheckDbName\x12\x1e\n\ntechnology\x18\x07 \x01(\tR\ntechnology\x12\x39\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1b\n\texpire_at\x18\t \x01(\tR\x08\x65xpireAt\x12:\n\x1a\x64\x62_discovery_job_wait_time\x18\n \x01(\tR\x16\x64\x62\x44iscoveryJobWaitTime\x12<\n\x1b\x64\x62_discovery_native_role_id\x18\x0b \x01(\tR\x17\x64\x62\x44iscoveryNativeRoleId\x12\x36\n\x17\x64\x65\x66\x61ult_access_behavior\x18\x0c \x01(\tR\x15\x64\x65\x66\x61ultAccessBehavior\x12\x39\n\x0blinked_logs\x18\r \x03(\x0b\x32\x18.admin.v1.IntegrationLogR\nlinkedLogs\x12 \n\x0b\x65nvironment\x18\x0e \x01(\tR\x0b\x65nvironment\x12\x35\n\x16termination_protection\x18\x0f \x01(\x08R\x15terminationProtection\"g\n\x0eIntegrationLog\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x1d\n\ncreated_at\x18\x04 \x01(\x05R\tcreatedAt2\xac\x08\n\x10\x44\x61taStoreService\x12V\n\x0f\x43reateDatastore\x12 .admin.v1.CreateDatastoreRequest\x1a!.admin.v1.CreateDatastoreResponse\x12M\n\x0cGetDatastore\x12\x1d.admin.v1.GetDatastoreRequest\x1a\x1e.admin.v1.GetDatastoreResponse\x12P\n\rGetDatastores\x12\x1e.admin.v1.GetDatastoresRequest\x1a\x1f.admin.v1.GetDatastoresResponse\x12\\\n\x11GetLinkedSidecars\x12\".admin.v1.GetLinkedSidecarsRequest\x1a#.admin.v1.GetLinkedSidecarsResponse\x12V\n\x0f\x44\x65leteDatastore\x12 .admin.v1.DeleteDatastoreRequest\x1a!.admin.v1.DeleteDatastoreResponse\x12\x62\n\x13UpdateDatastoreName\x12$.admin.v1.UpdateDatastoreNameRequest\x1a%.admin.v1.UpdateDatastoreNameResponse\x12n\n\x17UpdateDbDiscoveryConfig\x12(.admin.v1.UpdateDbDiscoveryConfigRequest\x1a).admin.v1.UpdateDbDiscoveryConfigResponse\x12\x89\x01\n UpdateDataStoreHealthCheckDbName\x12\x31.admin.v1.UpdateDataStoreHealthCheckDbNameRequest\x1a\x32.admin.v1.UpdateDataStoreHealthCheckDbNameResponse\x12\x95\x01\n$UpdateDataStoreDefaultAccessBehavior\x12\x35.admin.v1.UpdateDataStoreDefaultAccessBehaviorRequest\x1a\x36.admin.v1.UpdateDataStoreDefaultAccessBehaviorResponse\x12q\n\x18SetTerminationProtection\x12).admin.v1.SetTerminationProtectionRequest\x1a*.admin.v1.SetTerminationProtectionResponseB\xa4\x01\n\x0c\x63om.admin.v1B\x0e\x44\x61tastoreProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.datastore_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\016DatastoreProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETDATASTORESREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_GETDATASTORESREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372B6\222\0013\"1r/R\004nameR\010hostnameR\004portR\ntechnologyR\013environment'
  _globals['_CREATEDATASTOREREQUEST']._serialized_start=139
  _globals['_CREATEDATASTOREREQUEST']._serialized_end=523
  _globals['_CREATEDATASTORERESPONSE']._serialized_start=525
  _globals['_CREATEDATASTORERESPONSE']._serialized_end=566
  _globals['_GETDATASTOREREQUEST']._serialized_start=568
  _globals['_GETDATASTOREREQUEST']._serialized_end=605
  _globals['_GETDATASTORERESPONSE']._serialized_start=607
  _globals['_GETDATASTORERESPONSE']._serialized_end=680
  _globals['_GETDATASTORESREQUEST']._serialized_start=683
  _globals['_GETDATASTORESREQUEST']._serialized_end=917
  _globals['_GETDATASTORESRESPONSE']._serialized_start=920
  _globals['_GETDATASTORESRESPONSE']._serialized_end=1066
  _globals['_DELETEDATASTOREREQUEST']._serialized_start=1068
  _globals['_DELETEDATASTOREREQUEST']._serialized_end=1108
  _globals['_DELETEDATASTORERESPONSE']._serialized_start=1110
  _globals['_DELETEDATASTORERESPONSE']._serialized_end=1135
  _globals['_UPDATEDATASTORENAMEREQUEST']._serialized_start=1137
  _globals['_UPDATEDATASTORENAMEREQUEST']._serialized_end=1201
  _globals['_UPDATEDATASTORENAMERESPONSE']._serialized_start=1203
  _globals['_UPDATEDATASTORENAMERESPONSE']._serialized_end=1232
  _globals['_UPDATEDBDISCOVERYCONFIGREQUEST']._serialized_start=1235
  _globals['_UPDATEDBDISCOVERYCONFIGREQUEST']._serialized_end=1405
  _globals['_UPDATEDBDISCOVERYCONFIGRESPONSE']._serialized_start=1407
  _globals['_UPDATEDBDISCOVERYCONFIGRESPONSE']._serialized_end=1440
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMEREQUEST']._serialized_start=1442
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMEREQUEST']._serialized_end=1548
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMERESPONSE']._serialized_start=1550
  _globals['_UPDATEDATASTOREHEALTHCHECKDBNAMERESPONSE']._serialized_end=1592
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORREQUEST']._serialized_start=1594
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORREQUEST']._serialized_end=1711
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORRESPONSE']._serialized_start=1713
  _globals['_UPDATEDATASTOREDEFAULTACCESSBEHAVIORRESPONSE']._serialized_end=1759
  _globals['_SETTERMINATIONPROTECTIONREQUEST']._serialized_start=1761
  _globals['_SETTERMINATIONPROTECTIONREQUEST']._serialized_end=1865
  _globals['_SETTERMINATIONPROTECTIONRESPONSE']._serialized_start=1867
  _globals['_SETTERMINATIONPROTECTIONRESPONSE']._serialized_end=1901
  _globals['_GETLINKEDSIDECARSREQUEST']._serialized_start=1903
  _globals['_GETLINKEDSIDECARSREQUEST']._serialized_end=1945
  _globals['_GETLINKEDSIDECARSRESPONSE']._serialized_start=1947
  _globals['_GETLINKEDSIDECARSRESPONSE']._serialized_end=2027
  _globals['_LINKEDSIDECAR']._serialized_start=2029
  _globals['_LINKEDSIDECAR']._serialized_end=2133
  _globals['_DATASTORE']._serialized_start=2136
  _globals['_DATASTORE']._serialized_end=2761
  _globals['_INTEGRATIONLOG']._serialized_start=2763
  _globals['_INTEGRATIONLOG']._serialized_end=2866
  _globals['_DATASTORESERVICE']._serialized_start=2869
  _globals['_DATASTORESERVICE']._serialized_end=3937
# @@protoc_insertion_point(module_scope)
