# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_sso.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_sso.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import connection_pb2 as admin_dot_v1_dot_types_dot_v1_dot_connection__pb2
from .types.v1 import organization_pb2 as admin_dot_v1_dot_types_dot_v1_dot_organization__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_sso.proto\x12\x08\x61\x64min.v1\x1a\"admin/v1/types/v1/connection.proto\x1a$admin/v1/types/v1/organization.proto\"\x15\n\x13GetWorkOsOrgRequest\"x\n\x14GetWorkOsOrgResponse\x12>\n\nworkos_org\x18\x01 \x01(\x0b\x32\x1f.admin.v1.types.v1.OrganizationR\tworkosOrg\x12 \n\x0cself_sign_up\x18\x02 \x01(\x08R\nselfSignUp\"T\n\x16UpdateWorkOsOrgRequest\x12\x18\n\x07\x64omains\x18\x01 \x03(\tR\x07\x64omains\x12 \n\x0cself_sign_up\x18\x02 \x01(\x08R\nselfSignUp\"\x19\n\x17UpdateWorkOsOrgResponse\"\x1a\n\x18GetSsoConnectionsRequest\"\\\n\x19GetSsoConnectionsResponse\x12?\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ConnectionR\x0b\x63onnections\")\n\x17\x44\x65leteConnectionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1a\n\x18\x44\x65leteConnectionResponse2\xec\x02\n\nSsoService\x12M\n\x0cGetWorkOsOrg\x12\x1d.admin.v1.GetWorkOsOrgRequest\x1a\x1e.admin.v1.GetWorkOsOrgResponse\x12V\n\x0fUpdateWorkOsOrg\x12 .admin.v1.UpdateWorkOsOrgRequest\x1a!.admin.v1.UpdateWorkOsOrgResponse\x12\\\n\x11GetSsoConnections\x12\".admin.v1.GetSsoConnectionsRequest\x1a#.admin.v1.GetSsoConnectionsResponse\x12Y\n\x10\x44\x65leteConnection\x12!.admin.v1.DeleteConnectionRequest\x1a\".admin.v1.DeleteConnectionResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x13IntegrationSsoProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_sso_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationSsoProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETWORKOSORGREQUEST']._serialized_start=118
  _globals['_GETWORKOSORGREQUEST']._serialized_end=139
  _globals['_GETWORKOSORGRESPONSE']._serialized_start=141
  _globals['_GETWORKOSORGRESPONSE']._serialized_end=261
  _globals['_UPDATEWORKOSORGREQUEST']._serialized_start=263
  _globals['_UPDATEWORKOSORGREQUEST']._serialized_end=347
  _globals['_UPDATEWORKOSORGRESPONSE']._serialized_start=349
  _globals['_UPDATEWORKOSORGRESPONSE']._serialized_end=374
  _globals['_GETSSOCONNECTIONSREQUEST']._serialized_start=376
  _globals['_GETSSOCONNECTIONSREQUEST']._serialized_end=402
  _globals['_GETSSOCONNECTIONSRESPONSE']._serialized_start=404
  _globals['_GETSSOCONNECTIONSRESPONSE']._serialized_end=496
  _globals['_DELETECONNECTIONREQUEST']._serialized_start=498
  _globals['_DELETECONNECTIONREQUEST']._serialized_end=539
  _globals['_DELETECONNECTIONRESPONSE']._serialized_start=541
  _globals['_DELETECONNECTIONRESPONSE']._serialized_end=567
  _globals['_SSOSERVICE']._serialized_start=570
  _globals['_SSOSERVICE']._serialized_end=934
# @@protoc_insertion_point(module_scope)
