# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/etl.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/etl.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import datastore_pb2 as admin_dot_v1_dot_types_dot_v1_dot_datastore__pb2
from .types.v1 import etl_pb2 as admin_dot_v1_dot_types_dot_v1_dot_etl__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61\x64min/v1/etl.proto\x12\x08\x61\x64min.v1\x1a!admin/v1/types/v1/datastore.proto\x1a\x1b\x61\x64min/v1/types/v1/etl.proto\"\x12\n\x10GetGroupsRequest\"H\n\x11GetGroupsResponse\x12\x33\n\x06groups\x18\x01 \x03(\x0b\x32\x1b.admin.v1.types.v1.ETLGroupR\x06groups\"2\n\x14GetConnectorsRequest\x12\x1a\n\x08hostname\x18\x01 \x01(\tR\x08hostname\"X\n\x15GetConnectorsResponse\x12?\n\nconnectors\x18\x01 \x03(\x0b\x32\x1f.admin.v1.types.v1.ETLConnectorR\nconnectors\"R\n\x1bGetConnectorByDbNameRequest\x12\x1a\n\x08hostname\x18\x01 \x01(\tR\x08hostname\x12\x17\n\x07\x64\x62_name\x18\x02 \x01(\tR\x06\x64\x62Name\"\x99\x01\n\x1cGetConnectorByDbNameResponse\x12=\n\tconnector\x18\x01 \x01(\x0b\x32\x1f.admin.v1.types.v1.ETLConnectorR\tconnector\x12:\n\tdatastore\x18\x02 \x01(\x0b\x32\x1c.admin.v1.types.v1.DatastoreR\tdatastore\"4\n\x16GetDestinationsRequest\x12\x1a\n\x08hostname\x18\x01 \x01(\tR\x08hostname\"`\n\x17GetDestinationsResponse\x12\x45\n\x0c\x64\x65stinations\x18\x01 \x03(\x0b\x32!.admin.v1.types.v1.ETLDestinationR\x0c\x64\x65stinations\"+\n\x19GetDestinationByIDRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x9d\x01\n\x1aGetDestinationByIDResponse\x12\x43\n\x0b\x64\x65stination\x18\x01 \x01(\x0b\x32!.admin.v1.types.v1.ETLDestinationR\x0b\x64\x65stination\x12:\n\tdatastore\x18\x02 \x01(\x0b\x32\x1c.admin.v1.types.v1.DatastoreR\tdatastore\"=\n\x18GetLineageSchemasRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\"Z\n\x19GetLineageSchemasResponse\x12=\n\x07schemas\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.ETLSchemaLineageR\x07schemas\"c\n\x1dGetLineageSchemaByNameRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12\x1f\n\x0bschema_name\x18\x02 \x01(\tR\nschemaName\"]\n\x1eGetLineageSchemaByNameResponse\x12;\n\x06schema\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.ETLSchemaLineageR\x06schema\"<\n\x17GetLineageTablesRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\"V\n\x18GetLineageTablesResponse\x12:\n\x06tables\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.ETLTableLineageR\x06tables\"}\n\x1cGetLineageTableByNameRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12\x1b\n\tschema_id\x18\x02 \x01(\tR\x08schemaId\x12\x1d\n\ntable_name\x18\x03 \x01(\tR\ttableName\"Y\n\x1dGetLineageTableByNameResponse\x12\x38\n\x05table\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.ETLTableLineageR\x05table\"=\n\x18GetLineageColumnsRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\"Z\n\x19GetLineageColumnsResponse\x12=\n\x07\x63olumns\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.ETLColumnLineageR\x07\x63olumns\"_\n\x1fGetLineageColumnsByTableRequest\x12!\n\x0c\x63onnector_id\x18\x01 \x01(\tR\x0b\x63onnectorId\x12\x19\n\x08table_id\x18\x02 \x01(\tR\x07tableId\"a\n GetLineageColumnsByTableResponse\x12=\n\x07\x63olumns\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.ETLColumnLineageR\x07\x63olumns2\xbb\x08\n\nETLService\x12R\n\rGetConnectors\x12\x1e.admin.v1.GetConnectorsRequest\x1a\x1f.admin.v1.GetConnectorsResponse\"\x00\x12g\n\x14GetConnectorByDbName\x12%.admin.v1.GetConnectorByDbNameRequest\x1a&.admin.v1.GetConnectorByDbNameResponse\"\x00\x12X\n\x0fGetDestinations\x12 .admin.v1.GetDestinationsRequest\x1a!.admin.v1.GetDestinationsResponse\"\x00\x12\x61\n\x12GetDestinationByID\x12#.admin.v1.GetDestinationByIDRequest\x1a$.admin.v1.GetDestinationByIDResponse\"\x00\x12\x46\n\tGetGroups\x12\x1a.admin.v1.GetGroupsRequest\x1a\x1b.admin.v1.GetGroupsResponse\"\x00\x12^\n\x11GetLineageSchemas\x12\".admin.v1.GetLineageSchemasRequest\x1a#.admin.v1.GetLineageSchemasResponse\"\x00\x12m\n\x16GetLineageSchemaByName\x12\'.admin.v1.GetLineageSchemaByNameRequest\x1a(.admin.v1.GetLineageSchemaByNameResponse\"\x00\x12[\n\x10GetLineageTables\x12!.admin.v1.GetLineageTablesRequest\x1a\".admin.v1.GetLineageTablesResponse\"\x00\x12j\n\x15GetLineageTableByName\x12&.admin.v1.GetLineageTableByNameRequest\x1a\'.admin.v1.GetLineageTableByNameResponse\"\x00\x12^\n\x11GetLineageColumns\x12\".admin.v1.GetLineageColumnsRequest\x1a#.admin.v1.GetLineageColumnsResponse\"\x00\x12s\n\x18GetLineageColumnsByTable\x12).admin.v1.GetLineageColumnsByTableRequest\x1a*.admin.v1.GetLineageColumnsByTableResponse\"\x00\x42\x9e\x01\n\x0c\x63om.admin.v1B\x08\x45tlProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.etl_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\010EtlProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETGROUPSREQUEST']._serialized_start=96
  _globals['_GETGROUPSREQUEST']._serialized_end=114
  _globals['_GETGROUPSRESPONSE']._serialized_start=116
  _globals['_GETGROUPSRESPONSE']._serialized_end=188
  _globals['_GETCONNECTORSREQUEST']._serialized_start=190
  _globals['_GETCONNECTORSREQUEST']._serialized_end=240
  _globals['_GETCONNECTORSRESPONSE']._serialized_start=242
  _globals['_GETCONNECTORSRESPONSE']._serialized_end=330
  _globals['_GETCONNECTORBYDBNAMEREQUEST']._serialized_start=332
  _globals['_GETCONNECTORBYDBNAMEREQUEST']._serialized_end=414
  _globals['_GETCONNECTORBYDBNAMERESPONSE']._serialized_start=417
  _globals['_GETCONNECTORBYDBNAMERESPONSE']._serialized_end=570
  _globals['_GETDESTINATIONSREQUEST']._serialized_start=572
  _globals['_GETDESTINATIONSREQUEST']._serialized_end=624
  _globals['_GETDESTINATIONSRESPONSE']._serialized_start=626
  _globals['_GETDESTINATIONSRESPONSE']._serialized_end=722
  _globals['_GETDESTINATIONBYIDREQUEST']._serialized_start=724
  _globals['_GETDESTINATIONBYIDREQUEST']._serialized_end=767
  _globals['_GETDESTINATIONBYIDRESPONSE']._serialized_start=770
  _globals['_GETDESTINATIONBYIDRESPONSE']._serialized_end=927
  _globals['_GETLINEAGESCHEMASREQUEST']._serialized_start=929
  _globals['_GETLINEAGESCHEMASREQUEST']._serialized_end=990
  _globals['_GETLINEAGESCHEMASRESPONSE']._serialized_start=992
  _globals['_GETLINEAGESCHEMASRESPONSE']._serialized_end=1082
  _globals['_GETLINEAGESCHEMABYNAMEREQUEST']._serialized_start=1084
  _globals['_GETLINEAGESCHEMABYNAMEREQUEST']._serialized_end=1183
  _globals['_GETLINEAGESCHEMABYNAMERESPONSE']._serialized_start=1185
  _globals['_GETLINEAGESCHEMABYNAMERESPONSE']._serialized_end=1278
  _globals['_GETLINEAGETABLESREQUEST']._serialized_start=1280
  _globals['_GETLINEAGETABLESREQUEST']._serialized_end=1340
  _globals['_GETLINEAGETABLESRESPONSE']._serialized_start=1342
  _globals['_GETLINEAGETABLESRESPONSE']._serialized_end=1428
  _globals['_GETLINEAGETABLEBYNAMEREQUEST']._serialized_start=1430
  _globals['_GETLINEAGETABLEBYNAMEREQUEST']._serialized_end=1555
  _globals['_GETLINEAGETABLEBYNAMERESPONSE']._serialized_start=1557
  _globals['_GETLINEAGETABLEBYNAMERESPONSE']._serialized_end=1646
  _globals['_GETLINEAGECOLUMNSREQUEST']._serialized_start=1648
  _globals['_GETLINEAGECOLUMNSREQUEST']._serialized_end=1709
  _globals['_GETLINEAGECOLUMNSRESPONSE']._serialized_start=1711
  _globals['_GETLINEAGECOLUMNSRESPONSE']._serialized_end=1801
  _globals['_GETLINEAGECOLUMNSBYTABLEREQUEST']._serialized_start=1803
  _globals['_GETLINEAGECOLUMNSBYTABLEREQUEST']._serialized_end=1898
  _globals['_GETLINEAGECOLUMNSBYTABLERESPONSE']._serialized_start=1900
  _globals['_GETLINEAGECOLUMNSBYTABLERESPONSE']._serialized_end=1997
  _globals['_ETLSERVICE']._serialized_start=2000
  _globals['_ETLSERVICE']._serialized_end=3083
# @@protoc_insertion_point(module_scope)
