# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/cord.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/cord.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61\x64min/v1/cord.proto\x12\x08\x61\x64min.v1\"p\n\x19GetClientAuthTokenRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1b\n\tuser_name\x18\x02 \x01(\tR\x08userName\x12\x1d\n\nuser_email\x18\x03 \x01(\tR\tuserEmail\"2\n\x1aGetClientAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\"\x1a\n\x04test\x12\x12\n\x04test\x18\x01 \x01(\tR\x04test2p\n\x0b\x43ordService\x12\x61\n\x12GetClientAuthToken\x12#.admin.v1.GetClientAuthTokenRequest\x1a$.admin.v1.GetClientAuthTokenResponse\"\x00\x42\x9f\x01\n\x0c\x63om.admin.v1B\tCordProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.cord_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\tCordProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETCLIENTAUTHTOKENREQUEST']._serialized_start=33
  _globals['_GETCLIENTAUTHTOKENREQUEST']._serialized_end=145
  _globals['_GETCLIENTAUTHTOKENRESPONSE']._serialized_start=147
  _globals['_GETCLIENTAUTHTOKENRESPONSE']._serialized_end=197
  _globals['_TEST']._serialized_start=199
  _globals['_TEST']._serialized_end=225
  _globals['_CORDSERVICE']._serialized_start=227
  _globals['_CORDSERVICE']._serialized_end=339
# @@protoc_insertion_point(module_scope)
