# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/key.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/key.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61\x64min/v1/types/v1/key.proto\x12\x11\x61\x64min.v1.types.v1\"\xb6\x02\n\x03Key\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x63loud_region\x18\x02 \x01(\tR\x0b\x63loudRegion\x12\x15\n\x06key_id\x18\x03 \x01(\tR\x05keyId\x12\x17\n\x07key_arn\x18\x04 \x01(\tR\x06keyArn\x12\x16\n\x06\x61\x63tive\x18\x05 \x01(\x08R\x06\x61\x63tive\x12\x1d\n\nmanaged_by\x18\x06 \x01(\tR\tmanagedBy\x12\x19\n\x08key_type\x18\x07 \x01(\tR\x07keyType\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12(\n\x10\x63loud_account_id\x18\t \x01(\tR\x0e\x63loudAccountId\x12\x1d\n\ncreated_at\x18\n \x01(\tR\tcreatedAt\x12\x1d\n\nupdated_at\x18\x0b \x01(\tR\tupdatedAtB\xd6\x01\n\x15\x63om.admin.v1.types.v1B\x08KeyProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.key_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\010KeyProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_KEY']._serialized_start=51
  _globals['_KEY']._serialized_end=361
# @@protoc_insertion_point(module_scope)
