# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/sidecar.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/sidecar.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from .types.v1 import sidecar_pb2 as admin_dot_v1_dot_types_dot_v1_dot_sidecar__pb2
from .types.v1 import sidecar_link_pb2 as admin_dot_v1_dot_types_dot_v1_dot_sidecar__link__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/sidecar.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1f\x61\x64min/v1/types/v1/sidecar.proto\x1a$admin/v1/types/v1/sidecar_link.proto\x1a\x1avalidate/v1/validate.proto\"\xf5\x01\n\x13ListSidecarsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06search\x18\x04 \x01(\tR\x06search\x12\x81\x01\n\rsearch_fields\x18\x05 \x03(\tB\\\xfa\x42Y\x92\x01V\"TrRR\x04nameR\ntechnologyR\x0e\x63loud_providerR\x0c\x63loud_regionR\x0f\x66ormal_hostnameR\x0f\x64\x65ployment_typeR\x0csearchFields\"\x94\x01\n\x14ListSidecarsResponse\x12\x36\n\x08sidecars\x18\x01 \x03(\x0b\x32\x1a.admin.v1.types.v1.SidecarR\x08sidecars\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\";\n\x19GetSidecarVersionsRequest\x12\x1e\n\ntechnology\x18\x01 \x01(\tR\ntechnology\"8\n\x1aGetSidecarVersionsResponse\x12\x1a\n\x08versions\x18\x01 \x03(\tR\x08versions\"\xb1\x04\n\x14\x43reateSidecarRequest\x12,\n\x04name\x18\x01 \x01(\tB\x18\xfa\x42\x15r\x13\x10\x03\x18?2\r^[0-9a-z\\-]+$R\x04name\x12\x93\x01\n\ntechnology\x18\x02 \x01(\tBs\xfa\x42prnR\x08postgresR\x08redshiftR\x05mysqlR\x07mariadbR\tsnowflakeR\x02s3R\x08\x64ynamodbR\x07mongodbR\ndocumentdbR\x08\x62igqueryR\x04httpR\x03sshR\x05multiR\ntechnology\x12\'\n\x0f\x64\x65ployment_type\x18\x03 \x01(\tR\x0e\x64\x65ploymentType\x12!\n\x0c\x64\x61taplane_id\x18\x04 \x01(\tR\x0b\x64\x61taplaneId\x12!\n\x0c\x64\x61tastore_id\x18\x05 \x01(\tR\x0b\x64\x61tastoreId\x12\x1b\n\tfail_open\x18\x06 \x01(\x08R\x08\x66\x61ilOpen\x12,\n\x12global_kms_decrypt\x18\x07 \x01(\x08R\x10globalKmsDecrypt\x12\'\n\x0f\x66ormal_hostname\x18\x08 \x01(\tR\x0e\x66ormalHostname\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12!\n\x0cnetwork_type\x18\n \x01(\tR\x0bnetworkType\x12\x35\n\x16termination_protection\x18\x0b \x01(\x08R\x15terminationProtection\"\'\n\x15\x43reateSidecarResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\'\n\x15GetSidecarByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"N\n\x16GetSidecarByIdResponse\x12\x34\n\x07sidecar\x18\x01 \x01(\x0b\x32\x1a.admin.v1.types.v1.SidecarR\x07sidecar\"5\n#GetSidecarTlsCertificateByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\">\n$GetSidecarTlsCertificateByIdResponse\x12\x16\n\x06secret\x18\x01 \x01(\tR\x06secret\">\n\x18UpdateSidecarNameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\x1b\n\x19UpdateSidecarNameResponse\"G\n\x1bUpdateSidecarVersionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\"\x1e\n\x1cUpdateSidecarVersionResponse\"P\n\"UpdateSidecarFormalHostnameRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08hostname\x18\x02 \x01(\tR\x08hostname\"%\n#UpdateSidecarFormalHostnameResponse\"P\n$UpdateSidecarKmsDecryptPolicyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07\x65nabled\x18\x02 \x01(\x08R\x07\x65nabled\"\'\n%UpdateSidecarKmsDecryptPolicyResponse\"&\n\x14\x44\x65leteSidecarRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x17\n\x15\x44\x65leteSidecarResponse\"\xb0\x01\n!CreateSidecarDatastoreLinkRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x1d\n\nsidecar_id\x18\x02 \x01(\tR\tsidecarId\x12\x12\n\x04port\x18\x03 \x01(\x05R\x04port\x12\x35\n\x16termination_protection\x18\x04 \x01(\x08R\x15terminationProtection\"=\n\"CreateSidecarDatastoreLinkResponse\x12\x17\n\x07link_id\x18\x01 \x01(\tR\x06linkId\"<\n!DeleteSidecarDatastoreLinkRequest\x12\x17\n\x07link_id\x18\x01 \x01(\tR\x06linkId\"$\n\"DeleteSidecarDatastoreLinkResponse\"$\n\x12GetLinkByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"I\n\x13GetLinkByIdResponse\x12\x32\n\x04link\x18\x01 \x01(\x0b\x32\x1e.admin.v1.types.v1.SidecarLinkR\x04link\";\n\x1aGetLinksBySidecarIdRequest\x12\x1d\n\nsidecar_id\x18\x01 \x01(\tR\tsidecarId\"S\n\x1bGetLinksBySidecarIdResponse\x12\x34\n\x05links\x18\x01 \x03(\x0b\x32\x1e.admin.v1.types.v1.SidecarLinkR\x05links\"A\n\x1cGetLinksByDatastoreIdRequest\x12!\n\x0c\x64\x61tastore_id\x18\x02 \x01(\tR\x0b\x64\x61tastoreId\"U\n\x1dGetLinksByDatastoreIdResponse\x12\x34\n\x05links\x18\x01 \x03(\x0b\x32\x1e.admin.v1.types.v1.SidecarLinkR\x05links\"N\n\"UpdateTerminationProtectionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07\x65nabled\x18\x02 \x01(\x08R\x07\x65nabled\"%\n#UpdateTerminationProtectionResponse\"\x8a\x01\n!UpdateSidecarDatastoreLinkRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12:\n\x16termination_protection\x18\x02 \x01(\x08H\x00R\x15terminationProtection\x88\x01\x01\x42\x19\n\x17_termination_protection\"$\n\"UpdateSidecarDatastoreLinkResponse2\x9f\x0e\n\x0eSidecarService\x12O\n\x0cListSidecars\x12\x1d.admin.v1.ListSidecarsRequest\x1a\x1e.admin.v1.ListSidecarsResponse\"\x00\x12\x61\n\x12GetSidecarVersions\x12#.admin.v1.GetSidecarVersionsRequest\x1a$.admin.v1.GetSidecarVersionsResponse\"\x00\x12R\n\rCreateSidecar\x12\x1e.admin.v1.CreateSidecarRequest\x1a\x1f.admin.v1.CreateSidecarResponse\"\x00\x12U\n\x0eGetSidecarById\x12\x1f.admin.v1.GetSidecarByIdRequest\x1a .admin.v1.GetSidecarByIdResponse\"\x00\x12\x7f\n\x1cGetSidecarTlsCertificateById\x12-.admin.v1.GetSidecarTlsCertificateByIdRequest\x1a..admin.v1.GetSidecarTlsCertificateByIdResponse\"\x00\x12^\n\x11UpdateSidecarName\x12\".admin.v1.UpdateSidecarNameRequest\x1a#.admin.v1.UpdateSidecarNameResponse\"\x00\x12g\n\x14UpdateSidecarVersion\x12%.admin.v1.UpdateSidecarVersionRequest\x1a&.admin.v1.UpdateSidecarVersionResponse\"\x00\x12|\n\x1bUpdateSidecarFormalHostname\x12,.admin.v1.UpdateSidecarFormalHostnameRequest\x1a-.admin.v1.UpdateSidecarFormalHostnameResponse\"\x00\x12\x82\x01\n\x1dUpdateSidecarKmsDecryptPolicy\x12..admin.v1.UpdateSidecarKmsDecryptPolicyRequest\x1a/.admin.v1.UpdateSidecarKmsDecryptPolicyResponse\"\x00\x12|\n\x1bUpdateTerminationProtection\x12,.admin.v1.UpdateTerminationProtectionRequest\x1a-.admin.v1.UpdateTerminationProtectionResponse\"\x00\x12R\n\rDeleteSidecar\x12\x1e.admin.v1.DeleteSidecarRequest\x1a\x1f.admin.v1.DeleteSidecarResponse\"\x00\x12y\n\x1a\x43reateSidecarDatastoreLink\x12+.admin.v1.CreateSidecarDatastoreLinkRequest\x1a,.admin.v1.CreateSidecarDatastoreLinkResponse\"\x00\x12L\n\x0bGetLinkById\x12\x1c.admin.v1.GetLinkByIdRequest\x1a\x1d.admin.v1.GetLinkByIdResponse\"\x00\x12\x64\n\x13GetLinksBySidecarId\x12$.admin.v1.GetLinksBySidecarIdRequest\x1a%.admin.v1.GetLinksBySidecarIdResponse\"\x00\x12j\n\x15GetLinksByDatastoreId\x12&.admin.v1.GetLinksByDatastoreIdRequest\x1a\'.admin.v1.GetLinksByDatastoreIdResponse\"\x00\x12y\n\x1aUpdateSidecarDatastoreLink\x12+.admin.v1.UpdateSidecarDatastoreLinkRequest\x1a,.admin.v1.UpdateSidecarDatastoreLinkResponse\"\x00\x12y\n\x1a\x44\x65leteSidecarDatastoreLink\x12+.admin.v1.DeleteSidecarDatastoreLinkRequest\x1a,.admin.v1.DeleteSidecarDatastoreLinkResponse\"\x00\x42\xa2\x01\n\x0c\x63om.admin.v1B\x0cSidecarProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.sidecar_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\014SidecarProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTSIDECARSREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_LISTSIDECARSREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372BY\222\001V\"TrRR\004nameR\ntechnologyR\016cloud_providerR\014cloud_regionR\017formal_hostnameR\017deployment_type'
  _globals['_CREATESIDECARREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATESIDECARREQUEST'].fields_by_name['name']._serialized_options = b'\372B\025r\023\020\003\030?2\r^[0-9a-z\\-]+$'
  _globals['_CREATESIDECARREQUEST'].fields_by_name['technology']._loaded_options = None
  _globals['_CREATESIDECARREQUEST'].fields_by_name['technology']._serialized_options = b'\372BprnR\010postgresR\010redshiftR\005mysqlR\007mariadbR\tsnowflakeR\002s3R\010dynamodbR\007mongodbR\ndocumentdbR\010bigqueryR\004httpR\003sshR\005multi'
  _globals['_LISTSIDECARSREQUEST']._serialized_start=175
  _globals['_LISTSIDECARSREQUEST']._serialized_end=420
  _globals['_LISTSIDECARSRESPONSE']._serialized_start=423
  _globals['_LISTSIDECARSRESPONSE']._serialized_end=571
  _globals['_GETSIDECARVERSIONSREQUEST']._serialized_start=573
  _globals['_GETSIDECARVERSIONSREQUEST']._serialized_end=632
  _globals['_GETSIDECARVERSIONSRESPONSE']._serialized_start=634
  _globals['_GETSIDECARVERSIONSRESPONSE']._serialized_end=690
  _globals['_CREATESIDECARREQUEST']._serialized_start=693
  _globals['_CREATESIDECARREQUEST']._serialized_end=1254
  _globals['_CREATESIDECARRESPONSE']._serialized_start=1256
  _globals['_CREATESIDECARRESPONSE']._serialized_end=1295
  _globals['_GETSIDECARBYIDREQUEST']._serialized_start=1297
  _globals['_GETSIDECARBYIDREQUEST']._serialized_end=1336
  _globals['_GETSIDECARBYIDRESPONSE']._serialized_start=1338
  _globals['_GETSIDECARBYIDRESPONSE']._serialized_end=1416
  _globals['_GETSIDECARTLSCERTIFICATEBYIDREQUEST']._serialized_start=1418
  _globals['_GETSIDECARTLSCERTIFICATEBYIDREQUEST']._serialized_end=1471
  _globals['_GETSIDECARTLSCERTIFICATEBYIDRESPONSE']._serialized_start=1473
  _globals['_GETSIDECARTLSCERTIFICATEBYIDRESPONSE']._serialized_end=1535
  _globals['_UPDATESIDECARNAMEREQUEST']._serialized_start=1537
  _globals['_UPDATESIDECARNAMEREQUEST']._serialized_end=1599
  _globals['_UPDATESIDECARNAMERESPONSE']._serialized_start=1601
  _globals['_UPDATESIDECARNAMERESPONSE']._serialized_end=1628
  _globals['_UPDATESIDECARVERSIONREQUEST']._serialized_start=1630
  _globals['_UPDATESIDECARVERSIONREQUEST']._serialized_end=1701
  _globals['_UPDATESIDECARVERSIONRESPONSE']._serialized_start=1703
  _globals['_UPDATESIDECARVERSIONRESPONSE']._serialized_end=1733
  _globals['_UPDATESIDECARFORMALHOSTNAMEREQUEST']._serialized_start=1735
  _globals['_UPDATESIDECARFORMALHOSTNAMEREQUEST']._serialized_end=1815
  _globals['_UPDATESIDECARFORMALHOSTNAMERESPONSE']._serialized_start=1817
  _globals['_UPDATESIDECARFORMALHOSTNAMERESPONSE']._serialized_end=1854
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYREQUEST']._serialized_start=1856
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYREQUEST']._serialized_end=1936
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYRESPONSE']._serialized_start=1938
  _globals['_UPDATESIDECARKMSDECRYPTPOLICYRESPONSE']._serialized_end=1977
  _globals['_DELETESIDECARREQUEST']._serialized_start=1979
  _globals['_DELETESIDECARREQUEST']._serialized_end=2017
  _globals['_DELETESIDECARRESPONSE']._serialized_start=2019
  _globals['_DELETESIDECARRESPONSE']._serialized_end=2042
  _globals['_CREATESIDECARDATASTORELINKREQUEST']._serialized_start=2045
  _globals['_CREATESIDECARDATASTORELINKREQUEST']._serialized_end=2221
  _globals['_CREATESIDECARDATASTORELINKRESPONSE']._serialized_start=2223
  _globals['_CREATESIDECARDATASTORELINKRESPONSE']._serialized_end=2284
  _globals['_DELETESIDECARDATASTORELINKREQUEST']._serialized_start=2286
  _globals['_DELETESIDECARDATASTORELINKREQUEST']._serialized_end=2346
  _globals['_DELETESIDECARDATASTORELINKRESPONSE']._serialized_start=2348
  _globals['_DELETESIDECARDATASTORELINKRESPONSE']._serialized_end=2384
  _globals['_GETLINKBYIDREQUEST']._serialized_start=2386
  _globals['_GETLINKBYIDREQUEST']._serialized_end=2422
  _globals['_GETLINKBYIDRESPONSE']._serialized_start=2424
  _globals['_GETLINKBYIDRESPONSE']._serialized_end=2497
  _globals['_GETLINKSBYSIDECARIDREQUEST']._serialized_start=2499
  _globals['_GETLINKSBYSIDECARIDREQUEST']._serialized_end=2558
  _globals['_GETLINKSBYSIDECARIDRESPONSE']._serialized_start=2560
  _globals['_GETLINKSBYSIDECARIDRESPONSE']._serialized_end=2643
  _globals['_GETLINKSBYDATASTOREIDREQUEST']._serialized_start=2645
  _globals['_GETLINKSBYDATASTOREIDREQUEST']._serialized_end=2710
  _globals['_GETLINKSBYDATASTOREIDRESPONSE']._serialized_start=2712
  _globals['_GETLINKSBYDATASTOREIDRESPONSE']._serialized_end=2797
  _globals['_UPDATETERMINATIONPROTECTIONREQUEST']._serialized_start=2799
  _globals['_UPDATETERMINATIONPROTECTIONREQUEST']._serialized_end=2877
  _globals['_UPDATETERMINATIONPROTECTIONRESPONSE']._serialized_start=2879
  _globals['_UPDATETERMINATIONPROTECTIONRESPONSE']._serialized_end=2916
  _globals['_UPDATESIDECARDATASTORELINKREQUEST']._serialized_start=2919
  _globals['_UPDATESIDECARDATASTORELINKREQUEST']._serialized_end=3057
  _globals['_UPDATESIDECARDATASTORELINKRESPONSE']._serialized_start=3059
  _globals['_UPDATESIDECARDATASTORELINKRESPONSE']._serialized_end=3095
  _globals['_SIDECARSERVICE']._serialized_start=3098
  _globals['_SIDECARSERVICE']._serialized_end=4921
# @@protoc_insertion_point(module_scope)
