# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/flat_dataplane.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/flat_dataplane.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&admin/v1/types/v1/flat_dataplane.proto\x12\x11\x61\x64min.v1.types.v1\"\xdb\x10\n\rFlatDataplane\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x16\n\x06region\x18\x03 \x01(\tR\x06region\x12&\n\x0f\x63ustomer_vpc_id\x18\x04 \x01(\tR\rcustomerVpcId\x12\x37\n\x18original_customer_vpc_id\x18\x05 \x01(\tR\x15originalCustomerVpcId\x12(\n\x10\x63loud_account_id\x18\x06 \x01(\tR\x0e\x63loudAccountId\x12+\n\x11\x61vailability_zone\x18\x07 \x01(\x05R\x10\x61vailabilityZone\x12\x39\n\x19vpc_peering_connection_id\x18\x08 \x01(\tR\x16vpcPeeringConnectionId\x12G\n!formal_r53_private_hosted_zone_id\x18\t \x01(\tR\x1c\x66ormalR53PrivateHostedZoneId\x12\x41\n\x1e\x66ormal_vpc_flow_logs_group_arn\x18\n \x01(\tR\x19\x66ormalVpcFlowLogsGroupArn\x12\x41\n\x1e\x66ormal_vpc_flow_log_group_name\x18\x0b \x01(\tR\x19\x66ormalVpcFlowLogGroupName\x12\x46\n!formal_vpc_flow_logs_iam_role_arn\x18\x0c \x01(\tR\x1b\x66ormalVpcFlowLogsIamRoleArn\x12J\n#formal_vpc_flow_logs_iam_policy_arn\x18\r \x01(\tR\x1d\x66ormalVpcFlowLogsIamPolicyArn\x12)\n\x11\x66ormal_vpc_igw_id\x18\x0e \x01(\tR\x0e\x66ormalVpcIgwId\x12&\n\x0f\x65gress_only_igw\x18\x0f \x01(\tR\regressOnlyIgw\x12\x84\x01\n\x1e\x66ormal_vpc_private_subnets_ids\x18\x10 \x03(\x0b\x32@.admin.v1.types.v1.FlatDataplane.FormalVpcPrivateSubnetsIdsEntryR\x1a\x66ormalVpcPrivateSubnetsIds\x12\x81\x01\n\x1d\x66ormal_vpc_public_subnets_ids\x18\x11 \x03(\x0b\x32?.admin.v1.types.v1.FlatDataplane.FormalVpcPublicSubnetsIdsEntryR\x19\x66ormalVpcPublicSubnetsIds\x12\x32\n\x15\x66ormal_public_subnets\x18\x12 \x03(\tR\x13\x66ormalPublicSubnets\x12\x34\n\x16\x66ormal_private_subnets\x18\x13 \x03(\tR\x14\x66ormalPrivateSubnets\x12\x45\n formal_vpc_public_route_table_id\x18\x14 \x01(\tR\x1b\x66ormalVpcPublicRouteTableId\x12\x39\n\x19\x63ustomer_vpc_route_tables\x18\x15 \x03(\tR\x16\x63ustomerVpcRouteTables\x12\x65\n\x13\x66ormal_vpc_natg_ids\x18\x16 \x03(\x0b\x32\x36.admin.v1.types.v1.FlatDataplane.FormalVpcNatgIdsEntryR\x10\x66ormalVpcNatgIds\x12h\n\x14\x66ormal_vpc_natg_eips\x18\x17 \x03(\x0b\x32\x37.admin.v1.types.v1.FlatDataplane.FormalVpcNatgEipsEntryR\x11\x66ormalVpcNatgEips\x12\x42\n\x1e\x66ormal_vpc_public_route_tables\x18\x18 \x01(\tR\x1a\x66ormalVpcPublicRouteTables\x12O\n%formal_vpc_private_route_table_routes\x18\x19 \x03(\tR formalVpcPrivateRouteTableRoutes\x12\"\n\rformal_vpc_id\x18\x1a \x01(\tR\x0b\x66ormalVpcId\x12\x31\n\x15\x66ormal_vpc_cidr_block\x18\x1b \x01(\tR\x12\x66ormalVpcCidrBlock\x12(\n\x10\x65\x63s_cluster_name\x18\x1c \x01(\tR\x0e\x65\x63sClusterName\x12&\n\x0f\x65\x63s_cluster_arn\x18\x1d \x01(\tR\recsClusterArn\x12\x16\n\x06status\x18\x1e \x01(\tR\x06status\x12\x1f\n\x0bvpc_peering\x18\x1f \x01(\x08R\nvpcPeering\x1aM\n\x1f\x46ormalVpcPrivateSubnetsIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1aL\n\x1e\x46ormalVpcPublicSubnetsIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15\x46ormalVpcNatgIdsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x44\n\x16\x46ormalVpcNatgEipsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x8d\x02\n\x1d\x44\x61taplaneTransitGatewayRoutes\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12!\n\x0c\x64\x61taplane_id\x18\x02 \x01(\tR\x0b\x64\x61taplaneId\x12\x34\n\x16\x64\x65stination_cidr_block\x18\x03 \x01(\tR\x14\x64\x65stinationCidrBlock\x12,\n\x12transit_gateway_id\x18\x04 \x01(\tR\x10transitGatewayId\x12\x39\n\x19vpc_peering_connection_id\x18\x05 \x01(\tR\x16vpcPeeringConnectionId\x12\x1a\n\x08\x64\x65ployed\x18\x06 \x01(\x08R\x08\x64\x65ployed\"\xf2\x05\n\x10\x43loudIntegration\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\"\n\raws_formal_id\x18\x02 \x01(\tR\x0b\x61wsFormalId\x12,\n\x12\x63loud_account_name\x18\x03 \x01(\tR\x10\x63loudAccountName\x12\x10\n\x03url\x18\x04 \x01(\tR\x03url\x12%\n\x0e\x63loud_provider\x18\x05 \x01(\tR\rcloudProvider\x12$\n\x0e\x61ws_account_id\x18\x06 \x01(\tR\x0c\x61wsAccountId\x12-\n\x13\x61ws_formal_iam_role\x18\x07 \x01(\tR\x10\x61wsFormalIamRole\x12\x35\n\x17\x61ws_formal_handshake_id\x18\x08 \x01(\tR\x14\x61wsFormalHandshakeId\x12$\n\x0egcp_project_id\x18\t \x01(\tR\x0cgcpProjectId\x12#\n\rtemplate_body\x18\n \x01(\tR\x0ctemplateBody\x12/\n\x14\x61ws_formal_user_name\x18\x0b \x01(\tR\x11\x61wsFormalUserName\x12\x35\n\x17\x61ws_formal_pingback_arn\x18\x0c \x01(\tR\x14\x61wsFormalPingbackArn\x12\x31\n\x15\x61ws_formal_stack_name\x18\r \x01(\tR\x12\x61wsFormalStackName\x12(\n\x10\x61ws_cloud_region\x18\x0e \x01(\tR\x0e\x61wsCloudRegion\x12N\n%aws_formal_r53_private_hosted_zone_id\x18\x0f \x01(\tR\x1f\x61wsFormalR53PrivateHostedZoneId\x12\x38\n\x06stacks\x18\x10 \x03(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\x06stacks\x12\x1d\n\ncreated_at\x18\x11 \x01(\tR\tcreatedAtB\xe0\x01\n\x15\x63om.admin.v1.types.v1B\x12\x46latDataplaneProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.flat_dataplane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\022FlatDataplaneProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._loaded_options = None
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._serialized_options = b'8\001'
  _globals['_FLATDATAPLANE']._serialized_start=62
  _globals['_FLATDATAPLANE']._serialized_end=2201
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._serialized_start=1907
  _globals['_FLATDATAPLANE_FORMALVPCPRIVATESUBNETSIDSENTRY']._serialized_end=1984
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._serialized_start=1986
  _globals['_FLATDATAPLANE_FORMALVPCPUBLICSUBNETSIDSENTRY']._serialized_end=2062
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._serialized_start=2064
  _globals['_FLATDATAPLANE_FORMALVPCNATGIDSENTRY']._serialized_end=2131
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._serialized_start=2133
  _globals['_FLATDATAPLANE_FORMALVPCNATGEIPSENTRY']._serialized_end=2201
  _globals['_DATAPLANETRANSITGATEWAYROUTES']._serialized_start=2204
  _globals['_DATAPLANETRANSITGATEWAYROUTES']._serialized_end=2473
  _globals['_CLOUDINTEGRATION']._serialized_start=2476
  _globals['_CLOUDINTEGRATION']._serialized_end=3230
# @@protoc_insertion_point(module_scope)
