# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/outputs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/outputs.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\",\n\x11GetOutputsRequest\x12\x17\n\x07item_id\x18\x01 \x01(\tR\x06itemId\"F\n\x12GetOutputsResponse\x12\x30\n\x07records\x18\x01 \x03(\x0b\x32\x16.admin.v1.OutputRecordR\x07records\"\xa9\x01\n\x0cOutputRecord\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x17\n\x07item_id\x18\x02 \x01(\tR\x06itemId\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\x39\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x1b\n\tlog_level\x18\x05 \x01(\tR\x08logLevel2[\n\x0eOutputsService\x12I\n\nGetOutputs\x12\x1b.admin.v1.GetOutputsRequest\x1a\x1c.admin.v1.GetOutputsResponse\"\x00\x42\xa7\x01\n\x0c\x63om.admin.v1B\x0cOutputsProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.outputs_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\014OutputsProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETOUTPUTSREQUEST']._serialized_start=69
  _globals['_GETOUTPUTSREQUEST']._serialized_end=113
  _globals['_GETOUTPUTSRESPONSE']._serialized_start=115
  _globals['_GETOUTPUTSRESPONSE']._serialized_end=185
  _globals['_OUTPUTRECORD']._serialized_start=188
  _globals['_OUTPUTRECORD']._serialized_end=357
  _globals['_OUTPUTSSERVICE']._serialized_start=359
  _globals['_OUTPUTSSERVICE']._serialized_end=450
# @@protoc_insertion_point(module_scope)
