# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/identities.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/identities.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import external_id_pb2 as admin_dot_v1_dot_types_dot_v1_dot_external__id__pb2
from .types.v1 import group_pb2 as admin_dot_v1_dot_types_dot_v1_dot_group__pb2
from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from .types.v1 import user_pb2 as admin_dot_v1_dot_types_dot_v1_dot_user__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x64min/v1/identities.proto\x12\x08\x61\x64min.v1\x1a#admin/v1/types/v1/external_id.proto\x1a\x1d\x61\x64min/v1/types/v1/group.proto\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1c\x61\x64min/v1/types/v1/user.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"\xb3\x01\n\x11ListGroupsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06search\x18\x04 \x01(\tR\x06search\x12\x42\n\rsearch_fields\x18\x05 \x03(\tB\x1d\xfa\x42\x1a\x92\x01\x17\"\x15r\x13R\x04nameR\x0b\x64\x65scriptionR\x0csearchFields\"\x81\x01\n\x12\x43reateGroupRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12\x35\n\x16termination_protection\x18\x03 \x01(\x08R\x15terminationProtection\"%\n\x13GetGroupByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12\x44\x65leteGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb1\x01\n\x12UpdateGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12:\n\x16termination_protection\x18\x04 \x01(\x08H\x00R\x15terminationProtection\x88\x01\x01\x42\x19\n\x17_termination_protection\"D\n\x17LinkUsersToGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"F\n\x19LinkUsersToGroupV2Request\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"H\n\x1bUnlinkUsersFromGroupRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x19\n\x08user_ids\x18\x02 \x03(\tR\x07userIds\"E\n\x13\x43reateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"F\n\x14GetGroupByIdResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13\x44\x65leteGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"E\n\x13UpdateGroupResponse\x12.\n\x05group\x18\x01 \x01(\x0b\x32\x18.admin.v1.types.v1.GroupR\x05group\"\x8c\x01\n\x12ListGroupsResponse\x12\x30\n\x06groups\x18\x01 \x03(\x0b\x32\x18.admin.v1.types.v1.GroupR\x06groups\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"P\n\x18LinkUsersToGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"R\n\x1aLinkUsersToGroupV2Response\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"T\n\x1cUnlinkUsersFromGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"M\n\x15UserLinkGroupResponse\x12\x19\n\x08user_ids\x18\x01 \x03(\tR\x07userIds\x12\x19\n\x08group_id\x18\x02 \x01(\tR\x07groupId\"\xb2\x01\n\x10ListUsersRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\x12\x16\n\x06search\x18\x04 \x01(\tR\x06search\x12\x42\n\rsearch_fields\x18\x05 \x03(\tB\x1d\xfa\x42\x1a\x92\x01\x17\"\x15r\x13R\x0b\x64\x62_usernameR\x04typeR\x0csearchFields\"\x88\x01\n\x11ListUsersResponse\x12-\n\x05users\x18\x01 \x03(\x0b\x32\x17.admin.v1.types.v1.UserR\x05users\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\xef\x02\n\x11\x43reateUserRequest\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\x12\x35\n\x16termination_protection\x18\x0c \x01(\x08R\x15terminationProtection\"^\n\x12\x43reateUserResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\x12\x1b\n\ttenant_id\x18\x02 \x01(\tR\x08tenantId\"\xf1\x02\n\x13\x43reateUserV2Request\x12\x1d\n\nfirst_name\x18\x01 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x02 \x01(\tR\x08lastName\x12\x12\n\x04type\x18\x03 \x01(\tR\x04type\x12\x19\n\x08\x61pp_type\x18\x04 \x01(\tR\x07\x61ppType\x12\x15\n\x06\x61pp_id\x18\x05 \x01(\tR\x05\x61ppId\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12\x14\n\x05\x65mail\x18\x07 \x01(\tR\x05\x65mail\x12\x14\n\x05\x61\x64min\x18\x08 \x01(\x08R\x05\x61\x64min\x12\x10\n\x03idp\x18\t \x01(\tR\x03idp\x12\x16\n\x06status\x18\n \x01(\tR\x06status\x12\x37\n\texpire_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08\x65xpireAt\x12\x35\n\x16termination_protection\x18\x0c \x01(\x08R\x15terminationProtection\"&\n\x14\x43reateUserV2Response\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"$\n\x12GetUserByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"B\n\x13GetUserByIdResponse\x12+\n\x04user\x18\x01 \x01(\x0b\x32\x17.admin.v1.types.v1.UserR\x04user\"#\n\x11\x44\x65leteUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x14\n\x12\x44\x65leteUserResponse\"\xe0\x01\n\x11UpdateUserRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nfirst_name\x18\x03 \x01(\tR\tfirstName\x12\x1b\n\tlast_name\x18\x04 \x01(\tR\x08lastName\x12\x14\n\x05\x65mail\x18\x05 \x01(\tR\x05\x65mail\x12:\n\x16termination_protection\x18\x0c \x01(\x08H\x00R\x15terminationProtection\x88\x01\x01\x42\x19\n\x17_termination_protection\"\x14\n\x12UpdateUserResponse\"0\n\x1eGetMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"S\n\x1fGetMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"7\n\x1f\x43reateHumanUserAuthTokenRequest\x12\x14\n\x05\x65mail\x18\x01 \x01(\tR\x05\x65mail\"\x8f\x01\n CreateHumanUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12\x39\n\nexpires_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\"4\n\"RefreshMachineUserAuthTokenRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"W\n#RefreshMachineUserAuthTokenResponse\x12\x14\n\x05token\x18\x01 \x01(\tR\x05token\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\"+\n\x19GetUserExternalIdsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1aGetUserExternalIdsResponse\x12@\n\x0c\x65xternal_ids\x18\x01 \x03(\x0b\x32\x1d.admin.v1.types.v1.ExternalIdR\x0b\x65xternalIds\"\x8f\x01\n\x1aMapUserToExternalIdRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1f\n\x0b\x65xternal_id\x18\x02 \x01(\tR\nexternalId\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x15\n\x06\x61pp_id\x18\x04 \x01(\tR\x05\x61ppId\"\x1d\n\x1bMapUserToExternalIdResponse\"?\n\x1e\x44\x65leteExternalIdMappingRequest\x12\x1d\n\nmapping_id\x18\x01 \x01(\tR\tmappingId\"!\n\x1f\x44\x65leteExternalIdMappingResponse2\xdd\x08\n\x0bUserService\x12\x44\n\tListUsers\x12\x1a.admin.v1.ListUsersRequest\x1a\x1b.admin.v1.ListUsersResponse\x12G\n\nCreateUser\x12\x1b.admin.v1.CreateUserRequest\x1a\x1c.admin.v1.CreateUserResponse\x12M\n\x0c\x43reateUserV2\x12\x1d.admin.v1.CreateUserV2Request\x1a\x1e.admin.v1.CreateUserV2Response\x12J\n\x0bGetUserById\x12\x1c.admin.v1.GetUserByIdRequest\x1a\x1d.admin.v1.GetUserByIdResponse\x12G\n\nDeleteUser\x12\x1b.admin.v1.DeleteUserRequest\x1a\x1c.admin.v1.DeleteUserResponse\x12G\n\nUpdateUser\x12\x1b.admin.v1.UpdateUserRequest\x1a\x1c.admin.v1.UpdateUserResponse\x12n\n\x17GetMachineUserAuthToken\x12(.admin.v1.GetMachineUserAuthTokenRequest\x1a).admin.v1.GetMachineUserAuthTokenResponse\x12q\n\x18\x43reateHumanUserAuthToken\x12).admin.v1.CreateHumanUserAuthTokenRequest\x1a*.admin.v1.CreateHumanUserAuthTokenResponse\x12z\n\x1bRefreshMachineUserAuthToken\x12,.admin.v1.RefreshMachineUserAuthTokenRequest\x1a-.admin.v1.RefreshMachineUserAuthTokenResponse\x12_\n\x12GetUserExternalIds\x12#.admin.v1.GetUserExternalIdsRequest\x1a$.admin.v1.GetUserExternalIdsResponse\x12\x62\n\x13MapUserToExternalId\x12$.admin.v1.MapUserToExternalIdRequest\x1a%.admin.v1.MapUserToExternalIdResponse\x12n\n\x17\x44\x65leteExternalIdMapping\x12(.admin.v1.DeleteExternalIdMappingRequest\x1a).admin.v1.DeleteExternalIdMappingResponse2\xad\x05\n\x0cGroupService\x12J\n\x0b\x43reateGroup\x12\x1c.admin.v1.CreateGroupRequest\x1a\x1d.admin.v1.CreateGroupResponse\x12G\n\nListGroups\x12\x1b.admin.v1.ListGroupsRequest\x1a\x1c.admin.v1.ListGroupsResponse\x12M\n\x0cGetGroupById\x12\x1d.admin.v1.GetGroupByIdRequest\x1a\x1e.admin.v1.GetGroupByIdResponse\x12J\n\x0bUpdateGroup\x12\x1c.admin.v1.UpdateGroupRequest\x1a\x1d.admin.v1.UpdateGroupResponse\x12Y\n\x10LinkUsersToGroup\x12!.admin.v1.LinkUsersToGroupRequest\x1a\".admin.v1.LinkUsersToGroupResponse\x12_\n\x12LinkUsersToGroupV2\x12#.admin.v1.LinkUsersToGroupV2Request\x1a$.admin.v1.LinkUsersToGroupV2Response\x12\x65\n\x14UnlinkUsersFromGroup\x12%.admin.v1.UnlinkUsersFromGroupRequest\x1a&.admin.v1.UnlinkUsersFromGroupResponse\x12J\n\x0b\x44\x65leteGroup\x12\x1c.admin.v1.DeleteGroupRequest\x1a\x1d.admin.v1.DeleteGroupResponseB\xa5\x01\n\x0c\x63om.admin.v1B\x0fIdentitiesProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.identities_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\017IdentitiesProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_LISTGROUPSREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_LISTGROUPSREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372B\032\222\001\027\"\025r\023R\004nameR\013description'
  _globals['_LISTUSERSREQUEST'].fields_by_name['search_fields']._loaded_options = None
  _globals['_LISTUSERSREQUEST'].fields_by_name['search_fields']._serialized_options = b'\372B\032\222\001\027\"\025r\023R\013db_usernameR\004type'
  _globals['_LISTGROUPSREQUEST']._serialized_start=238
  _globals['_LISTGROUPSREQUEST']._serialized_end=417
  _globals['_CREATEGROUPREQUEST']._serialized_start=420
  _globals['_CREATEGROUPREQUEST']._serialized_end=549
  _globals['_GETGROUPBYIDREQUEST']._serialized_start=551
  _globals['_GETGROUPBYIDREQUEST']._serialized_end=588
  _globals['_DELETEGROUPREQUEST']._serialized_start=590
  _globals['_DELETEGROUPREQUEST']._serialized_end=626
  _globals['_UPDATEGROUPREQUEST']._serialized_start=629
  _globals['_UPDATEGROUPREQUEST']._serialized_end=806
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_start=808
  _globals['_LINKUSERSTOGROUPREQUEST']._serialized_end=876
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_start=878
  _globals['_LINKUSERSTOGROUPV2REQUEST']._serialized_end=948
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_start=950
  _globals['_UNLINKUSERSFROMGROUPREQUEST']._serialized_end=1022
  _globals['_CREATEGROUPRESPONSE']._serialized_start=1024
  _globals['_CREATEGROUPRESPONSE']._serialized_end=1093
  _globals['_GETGROUPBYIDRESPONSE']._serialized_start=1095
  _globals['_GETGROUPBYIDRESPONSE']._serialized_end=1165
  _globals['_DELETEGROUPRESPONSE']._serialized_start=1167
  _globals['_DELETEGROUPRESPONSE']._serialized_end=1236
  _globals['_UPDATEGROUPRESPONSE']._serialized_start=1238
  _globals['_UPDATEGROUPRESPONSE']._serialized_end=1307
  _globals['_LISTGROUPSRESPONSE']._serialized_start=1310
  _globals['_LISTGROUPSRESPONSE']._serialized_end=1450
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_start=1452
  _globals['_LINKUSERSTOGROUPRESPONSE']._serialized_end=1532
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_start=1534
  _globals['_LINKUSERSTOGROUPV2RESPONSE']._serialized_end=1616
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_start=1618
  _globals['_UNLINKUSERSFROMGROUPRESPONSE']._serialized_end=1702
  _globals['_USERLINKGROUPRESPONSE']._serialized_start=1704
  _globals['_USERLINKGROUPRESPONSE']._serialized_end=1781
  _globals['_LISTUSERSREQUEST']._serialized_start=1784
  _globals['_LISTUSERSREQUEST']._serialized_end=1962
  _globals['_LISTUSERSRESPONSE']._serialized_start=1965
  _globals['_LISTUSERSRESPONSE']._serialized_end=2101
  _globals['_CREATEUSERREQUEST']._serialized_start=2104
  _globals['_CREATEUSERREQUEST']._serialized_end=2471
  _globals['_CREATEUSERRESPONSE']._serialized_start=2473
  _globals['_CREATEUSERRESPONSE']._serialized_end=2567
  _globals['_CREATEUSERV2REQUEST']._serialized_start=2570
  _globals['_CREATEUSERV2REQUEST']._serialized_end=2939
  _globals['_CREATEUSERV2RESPONSE']._serialized_start=2941
  _globals['_CREATEUSERV2RESPONSE']._serialized_end=2979
  _globals['_GETUSERBYIDREQUEST']._serialized_start=2981
  _globals['_GETUSERBYIDREQUEST']._serialized_end=3017
  _globals['_GETUSERBYIDRESPONSE']._serialized_start=3019
  _globals['_GETUSERBYIDRESPONSE']._serialized_end=3085
  _globals['_DELETEUSERREQUEST']._serialized_start=3087
  _globals['_DELETEUSERREQUEST']._serialized_end=3122
  _globals['_DELETEUSERRESPONSE']._serialized_start=3124
  _globals['_DELETEUSERRESPONSE']._serialized_end=3144
  _globals['_UPDATEUSERREQUEST']._serialized_start=3147
  _globals['_UPDATEUSERREQUEST']._serialized_end=3371
  _globals['_UPDATEUSERRESPONSE']._serialized_start=3373
  _globals['_UPDATEUSERRESPONSE']._serialized_end=3393
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_start=3395
  _globals['_GETMACHINEUSERAUTHTOKENREQUEST']._serialized_end=3443
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=3445
  _globals['_GETMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=3528
  _globals['_CREATEHUMANUSERAUTHTOKENREQUEST']._serialized_start=3530
  _globals['_CREATEHUMANUSERAUTHTOKENREQUEST']._serialized_end=3585
  _globals['_CREATEHUMANUSERAUTHTOKENRESPONSE']._serialized_start=3588
  _globals['_CREATEHUMANUSERAUTHTOKENRESPONSE']._serialized_end=3731
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_start=3733
  _globals['_REFRESHMACHINEUSERAUTHTOKENREQUEST']._serialized_end=3785
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_start=3787
  _globals['_REFRESHMACHINEUSERAUTHTOKENRESPONSE']._serialized_end=3874
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_start=3876
  _globals['_GETUSEREXTERNALIDSREQUEST']._serialized_end=3919
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_start=3921
  _globals['_GETUSEREXTERNALIDSRESPONSE']._serialized_end=4015
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_start=4018
  _globals['_MAPUSERTOEXTERNALIDREQUEST']._serialized_end=4161
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_start=4163
  _globals['_MAPUSERTOEXTERNALIDRESPONSE']._serialized_end=4192
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_start=4194
  _globals['_DELETEEXTERNALIDMAPPINGREQUEST']._serialized_end=4257
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_start=4259
  _globals['_DELETEEXTERNALIDMAPPINGRESPONSE']._serialized_end=4292
  _globals['_USERSERVICE']._serialized_start=4295
  _globals['_USERSERVICE']._serialized_end=5412
  _globals['_GROUPSERVICE']._serialized_start=5415
  _globals['_GROUPSERVICE']._serialized_end=6100
# @@protoc_insertion_point(module_scope)
