# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: admin/v1/integration_incident.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import incident_account_pb2 as admin_dot_v1_dot_types_dot_v1_dot_incident__account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#admin/v1/integration_incident.proto\x12\x08\x61\x64min.v1\x1a(admin/v1/types/v1/incident_account.proto\"A\n DeleteIncidentAccountByIdRequest\x12\x1d\n\naccount_id\x18\x01 \x01(\tR\taccountId\"#\n!DeleteIncidentAccountByIdResponse\"t\n\x1d\x43onnectIncidentAccountRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x12\n\x04logo\x18\x03 \x01(\tR\x04logo\x12\x17\n\x07\x61pi_key\x18\x04 \x01(\tR\x06\x61piKey\"0\n\x1e\x43onnectIncidentAccountResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"c\n\x1aGetIncidentAccountsRequest\x12\x14\n\x05limit\x18\x01 \x01(\tR\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x17\n\x07go_back\x18\x03 \x01(\x08R\x06goBack\"\xa6\x01\n\x1bGetIncidentAccountsResponse\x12>\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\".admin.v1.types.v1.IncidentAccountR\x08\x61\x63\x63ounts\x12,\n\x12last_evaluated_key\x18\x02 \x01(\tR\x10lastEvaluatedKey\x12\x19\n\x08has_more\x18\x03 \x01(\x08R\x07hasMore\"/\n\x1dGetIncidentAccountByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"^\n\x1eGetIncidentAccountByIdResponse\x12<\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\".admin.v1.types.v1.IncidentAccountR\x07\x61\x63\x63ount2\xc5\x03\n\x0fIncidentService\x12k\n\x16\x43onnectIncidentAccount\x12\'.admin.v1.ConnectIncidentAccountRequest\x1a(.admin.v1.ConnectIncidentAccountResponse\x12\x62\n\x13GetIncidentAccounts\x12$.admin.v1.GetIncidentAccountsRequest\x1a%.admin.v1.GetIncidentAccountsResponse\x12k\n\x16GetIncidentAccountById\x12\'.admin.v1.GetIncidentAccountByIdRequest\x1a(.admin.v1.GetIncidentAccountByIdResponse\x12t\n\x19\x44\x65leteIncidentAccountById\x12*.admin.v1.DeleteIncidentAccountByIdRequest\x1a+.admin.v1.DeleteIncidentAccountByIdResponseB\xb3\x01\n\x0c\x63om.admin.v1B\x18IntegrationIncidentProtoP\x01ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_incident_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\014com.admin.v1B\030IntegrationIncidentProtoP\001ZHgithub.com/formalco/control-plane/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_DELETEINCIDENTACCOUNTBYIDREQUEST']._serialized_start=91
  _globals['_DELETEINCIDENTACCOUNTBYIDREQUEST']._serialized_end=156
  _globals['_DELETEINCIDENTACCOUNTBYIDRESPONSE']._serialized_start=158
  _globals['_DELETEINCIDENTACCOUNTBYIDRESPONSE']._serialized_end=193
  _globals['_CONNECTINCIDENTACCOUNTREQUEST']._serialized_start=195
  _globals['_CONNECTINCIDENTACCOUNTREQUEST']._serialized_end=311
  _globals['_CONNECTINCIDENTACCOUNTRESPONSE']._serialized_start=313
  _globals['_CONNECTINCIDENTACCOUNTRESPONSE']._serialized_end=361
  _globals['_GETINCIDENTACCOUNTSREQUEST']._serialized_start=363
  _globals['_GETINCIDENTACCOUNTSREQUEST']._serialized_end=462
  _globals['_GETINCIDENTACCOUNTSRESPONSE']._serialized_start=465
  _globals['_GETINCIDENTACCOUNTSRESPONSE']._serialized_end=631
  _globals['_GETINCIDENTACCOUNTBYIDREQUEST']._serialized_start=633
  _globals['_GETINCIDENTACCOUNTBYIDREQUEST']._serialized_end=680
  _globals['_GETINCIDENTACCOUNTBYIDRESPONSE']._serialized_start=682
  _globals['_GETINCIDENTACCOUNTBYIDRESPONSE']._serialized_end=776
  _globals['_INCIDENTSERVICE']._serialized_start=779
  _globals['_INCIDENTSERVICE']._serialized_end=1232
# @@protoc_insertion_point(module_scope)
