# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_kms.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_kms.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import key_pb2 as admin_dot_v1_dot_types_dot_v1_dot_key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/integration_kms.proto\x12\x08\x61\x64min.v1\x1a\x1b\x61\x64min/v1/types/v1/key.proto\"\xd7\x01\n\x1c\x43reateKeyRegistrationRequest\x12!\n\x0c\x63loud_region\x18\x01 \x01(\tR\x0b\x63loudRegion\x12\x15\n\x06key_id\x18\x02 \x01(\tR\x05keyId\x12\x1d\n\nmanaged_by\x18\x03 \x01(\tR\tmanagedBy\x12\x19\n\x08key_type\x18\x04 \x01(\tR\x07keyType\x12\x19\n\x08key_name\x18\x05 \x01(\tR\x07keyName\x12(\n\x10\x63loud_account_id\x18\x06 \x01(\tR\x0e\x63loudAccountId\"I\n\x1d\x43reateKeyRegistrationResponse\x12(\n\x03key\x18\x01 \x01(\x0b\x32\x16.admin.v1.types.v1.KeyR\x03key\":\n\x0eGetKeysRequest\x12(\n\x10\x66ilter_by_status\x18\x01 \x01(\tR\x0e\x66ilterByStatus\"=\n\x0fGetKeysResponse\x12*\n\x04keys\x18\x01 \x03(\x0b\x32\x16.admin.v1.types.v1.KeyR\x04keys\"\x1f\n\rGetKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\":\n\x0eGetKeyResponse\x12(\n\x03key\x18\x01 \x01(\x0b\x32\x16.admin.v1.types.v1.KeyR\x03key\"5\n#DeactivateFieldEncryptionKeyRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"&\n$DeactivateFieldEncryptionKeyResponse2\xf2\x02\n\nKmsService\x12h\n\x15\x43reateKeyRegistration\x12&.admin.v1.CreateKeyRegistrationRequest\x1a\'.admin.v1.CreateKeyRegistrationResponse\x12>\n\x07GetKeys\x12\x18.admin.v1.GetKeysRequest\x1a\x19.admin.v1.GetKeysResponse\x12;\n\x06GetKey\x12\x17.admin.v1.GetKeyRequest\x1a\x18.admin.v1.GetKeyResponse\x12}\n\x1c\x44\x65\x61\x63tivateFieldEncryptionKey\x12-.admin.v1.DeactivateFieldEncryptionKeyRequest\x1a..admin.v1.DeactivateFieldEncryptionKeyResponseB\xa9\x01\n\x0c\x63om.admin.v1B\x13IntegrationKmsProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_kms_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\023IntegrationKmsProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEKEYREGISTRATIONREQUEST']._serialized_start=74
  _globals['_CREATEKEYREGISTRATIONREQUEST']._serialized_end=289
  _globals['_CREATEKEYREGISTRATIONRESPONSE']._serialized_start=291
  _globals['_CREATEKEYREGISTRATIONRESPONSE']._serialized_end=364
  _globals['_GETKEYSREQUEST']._serialized_start=366
  _globals['_GETKEYSREQUEST']._serialized_end=424
  _globals['_GETKEYSRESPONSE']._serialized_start=426
  _globals['_GETKEYSRESPONSE']._serialized_end=487
  _globals['_GETKEYREQUEST']._serialized_start=489
  _globals['_GETKEYREQUEST']._serialized_end=520
  _globals['_GETKEYRESPONSE']._serialized_start=522
  _globals['_GETKEYRESPONSE']._serialized_end=580
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYREQUEST']._serialized_start=582
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYREQUEST']._serialized_end=635
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYRESPONSE']._serialized_start=637
  _globals['_DEACTIVATEFIELDENCRYPTIONKEYRESPONSE']._serialized_end=675
  _globals['_KMSSERVICE']._serialized_start=678
  _globals['_KMSSERVICE']._serialized_end=1048
# @@protoc_insertion_point(module_scope)
