# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/metrics.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/metrics.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61\x64min/v1/metrics.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"k\n\x11GetMetricsRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x03(\tR\x0b\x64\x61tastoreId\x12\x1a\n\x08interval\x18\x02 \x01(\tR\x08interval\x12\x17\n\x07user_id\x18\x03 \x03(\tR\x06userId\"\xa4\x06\n\x06Metric\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x1f\n\x0b\x63olumn_name\x18\x03 \x01(\tR\ncolumnName\x12\x1f\n\x0b\x63olumn_path\x18\x04 \x01(\tR\ncolumnPath\x12\x1d\n\ntable_name\x18\x05 \x01(\tR\ttableName\x12\x1d\n\ntable_path\x18\x06 \x01(\tR\ttablePath\x12\x1f\n\x0bschema_name\x18\x07 \x01(\tR\nschemaName\x12\x1f\n\x0bschema_path\x18\x08 \x01(\tR\nschemaPath\x12\x17\n\x07\x64\x62_name\x18\t \x01(\tR\x06\x64\x62Name\x12\x17\n\x07user_id\x18\n \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x0b \x01(\tR\x06\x64\x62User\x12\x1e\n\x0b\x65nd_user_id\x18\x0c \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\r \x01(\tR\x11\x65ndUserDbUsername\x12\x19\n\x08\x61pp_type\x18\x0e \x01(\tR\x07\x61ppType\x12!\n\x0c\x64\x61tastore_id\x18\x0f \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x10 \x01(\tR\rdatastoreName\x12*\n\x02ts\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x18\n\x07\x63ounter\x18\x12 \x01(\x04R\x07\x63ounter\x12#\n\rreturned_rows\x18\x13 \x01(\x03R\x0creturnedRows\x12\x1d\n\nip_address\x18\x14 \x01(\tR\tipAddress\x12\x1d\n\ndata_label\x18\x15 \x01(\tR\tdataLabel\x12\x1f\n\x0b\x64\x61ta_labels\x18\x16 \x03(\tR\ndataLabels\x12\x31\n\x14\x64\x61tastore_technology\x18\x17 \x01(\tR\x13\x64\x61tastoreTechnology\x12\x32\n\x06\x62ucket\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x06\x62ucket\"l\n\x04Node\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x14\n\x05shape\x18\x03 \x01(\tR\x05shape\x12\x14\n\x05\x63olor\x18\x04 \x01(\tR\x05\x63olor\x12\x14\n\x05label\x18\x05 \x01(\tR\x05label\"6\n\x04Link\x12\x16\n\x06source\x18\x01 \x01(\tR\x06source\x12\x16\n\x06target\x18\x02 \x01(\tR\x06target\"\x8c\x01\n\x12GetMetricsResponse\x12*\n\x07metrics\x18\x01 \x03(\x0b\x32\x10.admin.v1.MetricR\x07metrics\x12$\n\x05nodes\x18\x02 \x03(\x0b\x32\x0e.admin.v1.NodeR\x05nodes\x12$\n\x05links\x18\x03 \x03(\x0b\x32\x0e.admin.v1.LinkR\x05links\"\xf6\x04\n\x0eRowLevelMetric\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x02 \x01(\tR\rdatastoreName\x12\x1e\n\x0b\x65nd_user_id\x18\x03 \x01(\tR\tendUserId\x12/\n\x14\x65nd_user_db_username\x18\x04 \x01(\tR\x11\x65ndUserDbUsername\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x17\n\x07\x64\x62_user\x18\x06 \x01(\tR\x06\x64\x62User\x12\x17\n\x07\x64\x62_name\x18\x07 \x01(\tR\x06\x64\x62Name\x12\x1f\n\x0bschema_name\x18\x08 \x01(\tR\nschemaName\x12\x1d\n\ntable_name\x18\t \x01(\tR\ttableName\x12\x12\n\x04path\x18\n \x01(\tR\x04path\x12\x33\n\x16hashed_row_level_value\x18\x0b \x01(\tR\x13hashedRowLevelValue\x12:\n\x1a\x63lear_text_row_level_value\x18\x0c \x01(\tR\x16\x63learTextRowLevelValue\x12\x38\n\ttimestamp\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12#\n\rqueries_count\x18\x0e \x01(\x03R\x0cqueriesCount\x12\x1d\n\nrows_count\x18\x0f \x01(\x03R\trowsCount\x12;\n\x0btime_bucket\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ntimeBucket\"\xf1\x01\n\x1bRowLevelMetricConfiguration\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02id\x12\x1b\n\tmetric_id\x18\x03 \x01(\tR\x08metricId\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\x12\x33\n\x16\x61llow_clear_text_value\x18\x05 \x01(\x08R\x13\x61llowClearTextValue\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\"e\n\x1eGetCustomMetricsDetailsRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1a\n\x08interval\x18\x02 \x01(\tR\x08interval\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\"\xc3\x01\n\x1fGetCustomMetricsDetailsResponse\x12M\n\x06series\x18\x01 \x03(\x0b\x32\x35.admin.v1.GetCustomMetricsDetailsResponse.SeriesEntryR\x06series\x1aQ\n\x0bSeriesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x16.admin.v1.MetricsGroupR\x05value:\x02\x38\x01\"a\n\x0cMetricsGroup\x12\x32\n\x07metrics\x18\x01 \x03(\x0b\x32\x18.admin.v1.RowLevelMetricR\x07metrics\x12\x1d\n\nclear_text\x18\x02 \x01(\tR\tclearText\"\x19\n\x17GetCustomMetricsRequest\"\x88\x01\n\x18GetCustomMetricsResponse\x12l\n\x1frow_level_metric_configurations\x18\x01 \x03(\x0b\x32%.admin.v1.RowLevelMetricConfigurationR\x1crowLevelMetricConfigurations\"\x87\x01\n\x19\x43reateCustomMetricRequest\x12!\n\x0c\x64\x61tastore_id\x18\x01 \x01(\tR\x0b\x64\x61tastoreId\x12\x12\n\x04path\x18\x02 \x01(\tR\x04path\x12\x33\n\x16\x61llow_clear_text_value\x18\x03 \x01(\x08R\x13\x61llowClearTextValue\",\n\x1a\x43reateCustomMetricResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"+\n\x19\x44\x65leteCustomMetricRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1c\n\x1a\x44\x65leteCustomMetricResponse2\xf0\x03\n\x0eMetricsService\x12I\n\nGetMetrics\x12\x1b.admin.v1.GetMetricsRequest\x1a\x1c.admin.v1.GetMetricsResponse\"\x00\x12\x61\n\x12\x43reateCustomMetric\x12#.admin.v1.CreateCustomMetricRequest\x1a$.admin.v1.CreateCustomMetricResponse\"\x00\x12[\n\x10GetCustomMetrics\x12!.admin.v1.GetCustomMetricsRequest\x1a\".admin.v1.GetCustomMetricsResponse\"\x00\x12p\n\x17GetCustomMetricsDetails\x12(.admin.v1.GetCustomMetricsDetailsRequest\x1a).admin.v1.GetCustomMetricsDetailsResponse\"\x00\x12\x61\n\x12\x44\x65leteCustomMetric\x12#.admin.v1.DeleteCustomMetricRequest\x1a$.admin.v1.DeleteCustomMetricResponse\"\x00\x42\xa2\x01\n\x0c\x63om.admin.v1B\x0cMetricsProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.metrics_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\014MetricsProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._loaded_options = None
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._serialized_options = b'8\001'
  _globals['_GETMETRICSREQUEST']._serialized_start=69
  _globals['_GETMETRICSREQUEST']._serialized_end=176
  _globals['_METRIC']._serialized_start=179
  _globals['_METRIC']._serialized_end=983
  _globals['_NODE']._serialized_start=985
  _globals['_NODE']._serialized_end=1093
  _globals['_LINK']._serialized_start=1095
  _globals['_LINK']._serialized_end=1149
  _globals['_GETMETRICSRESPONSE']._serialized_start=1152
  _globals['_GETMETRICSRESPONSE']._serialized_end=1292
  _globals['_ROWLEVELMETRIC']._serialized_start=1295
  _globals['_ROWLEVELMETRIC']._serialized_end=1925
  _globals['_ROWLEVELMETRICCONFIGURATION']._serialized_start=1928
  _globals['_ROWLEVELMETRICCONFIGURATION']._serialized_end=2169
  _globals['_GETCUSTOMMETRICSDETAILSREQUEST']._serialized_start=2171
  _globals['_GETCUSTOMMETRICSDETAILSREQUEST']._serialized_end=2272
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE']._serialized_start=2275
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE']._serialized_end=2470
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._serialized_start=2389
  _globals['_GETCUSTOMMETRICSDETAILSRESPONSE_SERIESENTRY']._serialized_end=2470
  _globals['_METRICSGROUP']._serialized_start=2472
  _globals['_METRICSGROUP']._serialized_end=2569
  _globals['_GETCUSTOMMETRICSREQUEST']._serialized_start=2571
  _globals['_GETCUSTOMMETRICSREQUEST']._serialized_end=2596
  _globals['_GETCUSTOMMETRICSRESPONSE']._serialized_start=2599
  _globals['_GETCUSTOMMETRICSRESPONSE']._serialized_end=2735
  _globals['_CREATECUSTOMMETRICREQUEST']._serialized_start=2738
  _globals['_CREATECUSTOMMETRICREQUEST']._serialized_end=2873
  _globals['_CREATECUSTOMMETRICRESPONSE']._serialized_start=2875
  _globals['_CREATECUSTOMMETRICRESPONSE']._serialized_end=2919
  _globals['_DELETECUSTOMMETRICREQUEST']._serialized_start=2921
  _globals['_DELETECUSTOMMETRICREQUEST']._serialized_end=2964
  _globals['_DELETECUSTOMMETRICRESPONSE']._serialized_start=2966
  _globals['_DELETECUSTOMMETRICRESPONSE']._serialized_end=2994
  _globals['_METRICSSERVICE']._serialized_start=2997
  _globals['_METRICSSERVICE']._serialized_end=3493
# @@protoc_insertion_point(module_scope)
