# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/registry.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/registry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61\x64min/v1/registry.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbf\x01\n\x0eOnlineInstance\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\x12\x37\n\tlast_seen\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x08lastSeen\x12\x39\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\"f\n\rOnlineSidecar\x12\x1d\n\nsidecar_id\x18\x01 \x01(\tR\tsidecarId\x12\x36\n\tinstances\x18\x02 \x03(\x0b\x32\x18.admin.v1.OnlineInstanceR\tinstances\"\"\n GetOnlineInstancesByOrgIdRequest\"\xd0\x01\n!GetOnlineInstancesByOrgIdResponse\x12U\n\x08sidecars\x18\x01 \x03(\x0b\x32\x39.admin.v1.GetOnlineInstancesByOrgIdResponse.SidecarsEntryR\x08sidecars\x1aT\n\rSidecarsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.admin.v1.OnlineSidecarR\x05value:\x02\x38\x01\"E\n$GetOnlineInstancesBySidecarIdRequest\x12\x1d\n\nsidecar_id\x18\x01 \x01(\tR\tsidecarId\"_\n%GetOnlineInstancesBySidecarIdResponse\x12\x36\n\tinstances\x18\x01 \x03(\x0b\x32\x18.admin.v1.OnlineInstanceR\tinstances2\x8e\x02\n\x0fRegistryService\x12v\n\x19GetOnlineInstancesByOrgId\x12*.admin.v1.GetOnlineInstancesByOrgIdRequest\x1a+.admin.v1.GetOnlineInstancesByOrgIdResponse\"\x00\x12\x82\x01\n\x1dGetOnlineInstancesBySidecarId\x12..admin.v1.GetOnlineInstancesBySidecarIdRequest\x1a/.admin.v1.GetOnlineInstancesBySidecarIdResponse\"\x00\x42\xa3\x01\n\x0c\x63om.admin.v1B\rRegistryProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.registry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\rRegistryProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._loaded_options = None
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._serialized_options = b'8\001'
  _globals['_ONLINEINSTANCE']._serialized_start=71
  _globals['_ONLINEINSTANCE']._serialized_end=262
  _globals['_ONLINESIDECAR']._serialized_start=264
  _globals['_ONLINESIDECAR']._serialized_end=366
  _globals['_GETONLINEINSTANCESBYORGIDREQUEST']._serialized_start=368
  _globals['_GETONLINEINSTANCESBYORGIDREQUEST']._serialized_end=402
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE']._serialized_start=405
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE']._serialized_end=613
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._serialized_start=529
  _globals['_GETONLINEINSTANCESBYORGIDRESPONSE_SIDECARSENTRY']._serialized_end=613
  _globals['_GETONLINEINSTANCESBYSIDECARIDREQUEST']._serialized_start=615
  _globals['_GETONLINEINSTANCESBYSIDECARIDREQUEST']._serialized_end=684
  _globals['_GETONLINEINSTANCESBYSIDECARIDRESPONSE']._serialized_start=686
  _globals['_GETONLINEINSTANCESBYSIDECARIDRESPONSE']._serialized_end=781
  _globals['_REGISTRYSERVICE']._serialized_start=784
  _globals['_REGISTRYSERVICE']._serialized_end=1054
# @@protoc_insertion_point(module_scope)
