# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_cloud.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_cloud.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import flat_dataplane_pb2 as admin_dot_v1_dot_types_dot_v1_dot_flat__dataplane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n admin/v1/integration_cloud.proto\x12\x08\x61\x64min.v1\x1a&admin/v1/types/v1/flat_dataplane.proto\")\n\x17GetDataplaneByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"Z\n\x18GetDataplaneByIdResponse\x12>\n\tdataplane\x18\x01 \x01(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\tdataplane\"/\n\x1dGetDataplaneRoutesByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"}\n\x1eGetDataplaneRoutesByIdResponse\x12[\n\x10\x64\x61taplane_routes\x18\x01 \x01(\x0b\x32\x30.admin.v1.types.v1.DataplaneTransitGatewayRoutesR\x0f\x64\x61taplaneRoutes\"\x83\x01\n!CreateAwsConnectionSessionRequest\x12,\n\x12\x63loud_account_name\x18\x01 \x01(\tR\x10\x63loudAccountName\x12\x30\n\x14\x63loud_account_region\x18\x02 \x01(\tR\x12\x63loudAccountRegion\"v\n\"CreateAwsConnectionSessionResponse\x12P\n\x11\x63loud_integration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x10\x63loudIntegration\"3\n!DeleteAwsConnectionSessionRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"8\n&GetIntegrationsCloudAccountByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"p\n\'GetIntegrationsCloudAccountByIdResponse\x12\x45\n\x0bintegration\x18\x01 \x01(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0bintegration\"%\n#GetIntegrationsCloudAccountsRequest\"o\n$GetIntegrationsCloudAccountsResponse\x12G\n\x0cintegrations\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.CloudIntegrationR\x0cintegrations\"B\n!CreateGcpConnectionSessionRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\"$\n\"CreateGcpConnectionSessionResponse\"$\n\"DeleteAwsConnectionSessionResponse\"U\n)GetDataplaneStacksByCloudAccountIdRequest\x12(\n\x10\x63loud_account_id\x18\x01 \x01(\tR\x0e\x63loudAccountId\"n\n*GetDataplaneStacksByCloudAccountIdResponse\x12@\n\ndataplanes\x18\x01 \x03(\x0b\x32 .admin.v1.types.v1.FlatDataplaneR\ndataplanes2\xdb\x07\n\x0c\x43loudService\x12Y\n\x10GetDataplaneById\x12!.admin.v1.GetDataplaneByIdRequest\x1a\".admin.v1.GetDataplaneByIdResponse\x12k\n\x16GetDataplaneRoutesById\x12\'.admin.v1.GetDataplaneRoutesByIdRequest\x1a(.admin.v1.GetDataplaneRoutesByIdResponse\x12\x8f\x01\n\"GetDataplaneStacksByCloudAccountId\x12\x33.admin.v1.GetDataplaneStacksByCloudAccountIdRequest\x1a\x34.admin.v1.GetDataplaneStacksByCloudAccountIdResponse\x12w\n\x1a\x43reateAwsConnectionSession\x12+.admin.v1.CreateAwsConnectionSessionRequest\x1a,.admin.v1.CreateAwsConnectionSessionResponse\x12w\n\x1a\x44\x65leteAwsConnectionSession\x12+.admin.v1.DeleteAwsConnectionSessionRequest\x1a,.admin.v1.DeleteAwsConnectionSessionResponse\x12\x86\x01\n\x1fGetIntegrationsCloudAccountById\x12\x30.admin.v1.GetIntegrationsCloudAccountByIdRequest\x1a\x31.admin.v1.GetIntegrationsCloudAccountByIdResponse\x12}\n\x1cGetIntegrationsCloudAccounts\x12-.admin.v1.GetIntegrationsCloudAccountsRequest\x1a..admin.v1.GetIntegrationsCloudAccountsResponse\x12w\n\x1a\x43reateGcpConnectionSession\x12+.admin.v1.CreateGcpConnectionSessionRequest\x1a,.admin.v1.CreateGcpConnectionSessionResponseB\xab\x01\n\x0c\x63om.admin.v1B\x15IntegrationCloudProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_cloud_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\025IntegrationCloudProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_start=86
  _globals['_GETDATAPLANEBYIDREQUEST']._serialized_end=127
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_start=129
  _globals['_GETDATAPLANEBYIDRESPONSE']._serialized_end=219
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_start=221
  _globals['_GETDATAPLANEROUTESBYIDREQUEST']._serialized_end=268
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_start=270
  _globals['_GETDATAPLANEROUTESBYIDRESPONSE']._serialized_end=395
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_start=398
  _globals['_CREATEAWSCONNECTIONSESSIONREQUEST']._serialized_end=529
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=531
  _globals['_CREATEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=649
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_start=651
  _globals['_DELETEAWSCONNECTIONSESSIONREQUEST']._serialized_end=702
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_start=704
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDREQUEST']._serialized_end=760
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_start=762
  _globals['_GETINTEGRATIONSCLOUDACCOUNTBYIDRESPONSE']._serialized_end=874
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_start=876
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSREQUEST']._serialized_end=913
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_start=915
  _globals['_GETINTEGRATIONSCLOUDACCOUNTSRESPONSE']._serialized_end=1026
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_start=1028
  _globals['_CREATEGCPCONNECTIONSESSIONREQUEST']._serialized_end=1094
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_start=1096
  _globals['_CREATEGCPCONNECTIONSESSIONRESPONSE']._serialized_end=1132
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_start=1134
  _globals['_DELETEAWSCONNECTIONSESSIONRESPONSE']._serialized_end=1170
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_start=1172
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDREQUEST']._serialized_end=1257
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_start=1259
  _globals['_GETDATAPLANESTACKSBYCLOUDACCOUNTIDRESPONSE']._serialized_end=1369
  _globals['_CLOUDSERVICE']._serialized_start=1372
  _globals['_CLOUDSERVICE']._serialized_end=2359
# @@protoc_insertion_point(module_scope)
