# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/column.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/column.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/types/v1/column.proto\x12\x11\x61\x64min.v1.types.v1\"\xd9\x05\n\x06\x43olumn\x12\x1d\n\ncreated_at\x18\x01 \x01(\x03R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x02 \x01(\x03R\tupdatedAt\x12!\n\x0c\x64\x61tastore_id\x18\x03 \x01(\tR\x0b\x64\x61tastoreId\x12%\n\x0e\x64\x61tastore_name\x18\x04 \x01(\tR\rdatastoreName\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\x12*\n\x11table_physical_id\x18\x06 \x01(\tR\x0ftablePhysicalId\x12\x34\n\x16table_attribute_number\x18\x07 \x01(\x04R\x14tableAttributeNumber\x12\x12\n\x04name\x18\x08 \x01(\tR\x04name\x12\x14\n\x05\x61lias\x18\t \x01(\tR\x05\x61lias\x12\x1d\n\ntable_path\x18\n \x01(\tR\ttablePath\x12\x1d\n\ndata_label\x18\x0b \x01(\tR\tdataLabel\x12\x1b\n\tdata_type\x18\x0c \x01(\tR\x08\x64\x61taType\x12\"\n\rdata_type_oid\x18\r \x01(\rR\x0b\x64\x61taTypeOid\x12@\n\x1d\x64\x61ta_label_locked_for_sidecar\x18\x0e \x01(\x08R\x19\x64\x61taLabelLockedForSidecar\x12\x12\n\x04tags\x18\x0f \x03(\tR\x04tags\x12\x1c\n\tencrypted\x18\x10 \x01(\x08R\tencrypted\x12#\n\rpolicy_action\x18\x11 \x01(\tR\x0cpolicyAction\x12\x35\n\x17\x64\x65\x63rypted_at_query_time\x18\x12 \x01(\x08R\x14\x64\x65\x63ryptedAtQueryTime\x12\x30\n\x14\x64\x65\x63ryption_policy_id\x18\x13 \x01(\tR\x12\x64\x65\x63ryptionPolicyId\x12&\n\x0f\x64\x61ta_domain_ids\x18\x14 \x03(\tR\rdataDomainIdsB\xd9\x01\n\x15\x63om.admin.v1.types.v1B\x0b\x43olumnProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.column_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\013ColumnProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_COLUMN']._serialized_start=54
  _globals['_COLUMN']._serialized_end=783
# @@protoc_insertion_point(module_scope)
