# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import datastore_pb2 as admin_dot_v1_dot_datastore__pb2


class DataStoreServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateDatastore = channel.unary_unary(
                '/admin.v1.DataStoreService/CreateDatastore',
                request_serializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreResponse.FromString,
                _registered_method=True)
        self.GetDatastore = channel.unary_unary(
                '/admin.v1.DataStoreService/GetDatastore',
                request_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreResponse.FromString,
                _registered_method=True)
        self.GetDatastores = channel.unary_unary(
                '/admin.v1.DataStoreService/GetDatastores',
                request_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresResponse.FromString,
                _registered_method=True)
        self.GetLinkedSidecars = channel.unary_unary(
                '/admin.v1.DataStoreService/GetLinkedSidecars',
                request_serializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsResponse.FromString,
                _registered_method=True)
        self.DeleteDatastore = channel.unary_unary(
                '/admin.v1.DataStoreService/DeleteDatastore',
                request_serializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreResponse.FromString,
                _registered_method=True)
        self.UpdateDatastoreName = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDatastoreName',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameResponse.FromString,
                _registered_method=True)
        self.UpdateDbDiscoveryConfig = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDbDiscoveryConfig',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigResponse.FromString,
                _registered_method=True)
        self.UpdateDataStoreHealthCheckDbName = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDataStoreHealthCheckDbName',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameResponse.FromString,
                _registered_method=True)
        self.UpdateDataStoreDefaultAccessBehavior = channel.unary_unary(
                '/admin.v1.DataStoreService/UpdateDataStoreDefaultAccessBehavior',
                request_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorResponse.FromString,
                _registered_method=True)
        self.SetTerminationProtection = channel.unary_unary(
                '/admin.v1.DataStoreService/SetTerminationProtection',
                request_serializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionResponse.FromString,
                _registered_method=True)


class DataStoreServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDatastores(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLinkedSidecars(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDatastore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDatastoreName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDbDiscoveryConfig(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataStoreHealthCheckDbName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataStoreDefaultAccessBehavior(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTerminationProtection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataStoreServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDatastore,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.CreateDatastoreResponse.SerializeToString,
            ),
            'GetDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatastore,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoreResponse.SerializeToString,
            ),
            'GetDatastores': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDatastores,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.GetDatastoresResponse.SerializeToString,
            ),
            'GetLinkedSidecars': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLinkedSidecars,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsResponse.SerializeToString,
            ),
            'DeleteDatastore': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDatastore,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.DeleteDatastoreResponse.SerializeToString,
            ),
            'UpdateDatastoreName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDatastoreName,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameResponse.SerializeToString,
            ),
            'UpdateDbDiscoveryConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDbDiscoveryConfig,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigResponse.SerializeToString,
            ),
            'UpdateDataStoreHealthCheckDbName': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataStoreHealthCheckDbName,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameResponse.SerializeToString,
            ),
            'UpdateDataStoreDefaultAccessBehavior': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataStoreDefaultAccessBehavior,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorResponse.SerializeToString,
            ),
            'SetTerminationProtection': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTerminationProtection,
                    request_deserializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionRequest.FromString,
                    response_serializer=admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.DataStoreService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.DataStoreService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataStoreService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/CreateDatastore',
            admin_dot_v1_dot_datastore__pb2.CreateDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.CreateDatastoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/GetDatastore',
            admin_dot_v1_dot_datastore__pb2.GetDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.GetDatastoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDatastores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/GetDatastores',
            admin_dot_v1_dot_datastore__pb2.GetDatastoresRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.GetDatastoresResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetLinkedSidecars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/GetLinkedSidecars',
            admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.GetLinkedSidecarsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDatastore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/DeleteDatastore',
            admin_dot_v1_dot_datastore__pb2.DeleteDatastoreRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.DeleteDatastoreResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDatastoreName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDatastoreName',
            admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDatastoreNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDbDiscoveryConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDbDiscoveryConfig',
            admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDbDiscoveryConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDataStoreHealthCheckDbName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDataStoreHealthCheckDbName',
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreHealthCheckDbNameResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateDataStoreDefaultAccessBehavior(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/UpdateDataStoreDefaultAccessBehavior',
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.UpdateDataStoreDefaultAccessBehaviorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetTerminationProtection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.DataStoreService/SetTerminationProtection',
            admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionRequest.SerializeToString,
            admin_dot_v1_dot_datastore__pb2.SetTerminationProtectionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
