# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import integration_mfa_pb2 as admin_dot_v1_dot_integration__mfa__pb2


class IntegrationMfaServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListIntegrationMfas = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/ListIntegrationMfas',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasResponse.FromString,
                _registered_method=True)
        self.GetIntegrationMfaById = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/GetIntegrationMfaById',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdResponse.FromString,
                _registered_method=True)
        self.UpdateIntegrationMfa = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/UpdateIntegrationMfa',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaResponse.FromString,
                _registered_method=True)
        self.CreateIntegrationMfa = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/CreateIntegrationMfa',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaResponse.FromString,
                _registered_method=True)
        self.DeleteIntegrationMfa = channel.unary_unary(
                '/admin.v1.IntegrationMfaService/DeleteIntegrationMfa',
                request_serializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaResponse.FromString,
                _registered_method=True)


class IntegrationMfaServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListIntegrationMfas(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetIntegrationMfaById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateIntegrationMfa(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateIntegrationMfa(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteIntegrationMfa(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntegrationMfaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListIntegrationMfas': grpc.unary_unary_rpc_method_handler(
                    servicer.ListIntegrationMfas,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasResponse.SerializeToString,
            ),
            'GetIntegrationMfaById': grpc.unary_unary_rpc_method_handler(
                    servicer.GetIntegrationMfaById,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdResponse.SerializeToString,
            ),
            'UpdateIntegrationMfa': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateIntegrationMfa,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaResponse.SerializeToString,
            ),
            'CreateIntegrationMfa': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateIntegrationMfa,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaResponse.SerializeToString,
            ),
            'DeleteIntegrationMfa': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteIntegrationMfa,
                    request_deserializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaRequest.FromString,
                    response_serializer=admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.IntegrationMfaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.IntegrationMfaService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class IntegrationMfaService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListIntegrationMfas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/ListIntegrationMfas',
            admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.ListIntegrationMfasResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetIntegrationMfaById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/GetIntegrationMfaById',
            admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.GetIntegrationMfaByIdResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateIntegrationMfa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/UpdateIntegrationMfa',
            admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.UpdateIntegrationMfaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateIntegrationMfa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/CreateIntegrationMfa',
            admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.CreateIntegrationMfaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteIntegrationMfa(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.IntegrationMfaService/DeleteIntegrationMfa',
            admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaRequest.SerializeToString,
            admin_dot_v1_dot_integration__mfa__pb2.DeleteIntegrationMfaResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
