# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/policies.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/policies.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import list_metadata_pb2 as admin_dot_v1_dot_types_dot_v1_dot_list__metadata__pb2
from .types.v1 import policy_pb2 as admin_dot_v1_dot_types_dot_v1_dot_policy__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61\x64min/v1/policies.proto\x12\x08\x61\x64min.v1\x1a%admin/v1/types/v1/list_metadata.proto\x1a\x1e\x61\x64min/v1/types/v1/policy.proto\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"g\n\x1d\x43reatePolicySuggestionRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\"@\n\x1e\x43reatePolicySuggestionResponse\x12\x1e\n\nsuggestion\x18\x01 \x01(\tR\nsuggestion\".\n\x13\x44\x65letePolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x16\n\x14\x44\x65letePolicyResponse\"<\n\x1d\x45valuatePolicyValidityRequest\x12\x1b\n\x04\x63ode\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\"^\n\x1e\x45valuatePolicyValidityResponse\x12\x14\n\x05valid\x18\x01 \x01(\x08R\x05valid\x12\x10\n\x03\x61st\x18\x02 \x01(\tR\x03\x61st\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\"\xb4\x05\n\x15\x44ryRunPoliciesRequest\x12\x42\n\x10policy_rule_type\x18\x01 \x01(\x0e\x32\x18.admin.v1.PolicyRuleTypeR\x0epolicyRuleType\x12)\n\x10\x61pplication_name\x18\x02 \x01(\tR\x0f\x61pplicationName\x12*\n\x11\x63lient_ip_address\x18\x03 \x01(\tR\x0f\x63lientIpAddress\x12\x1d\n\nclient_tls\x18\x04 \x01(\x08R\tclientTls\x12%\n\x0estatement_type\x18\x05 \x01(\tR\rstatementType\x12\x17\n\x07\x64\x62_name\x18\x06 \x01(\tR\x06\x64\x62Name\x12!\n\x0cschema_paths\x18\x07 \x03(\tR\x0bschemaPaths\x12\x1f\n\x0btable_paths\x18\x08 \x03(\tR\ntablePaths\x12\x1f\n\x0b\x63olumn_tags\x18\t \x03(\tR\ncolumnTags\x12\x1f\n\x0b\x63olumn_name\x18\n \x01(\tR\ncolumnName\x12\x1f\n\x0b\x63olumn_path\x18\x0b \x01(\tR\ncolumnPath\x12\x1d\n\ndata_label\x18\x0c \x01(\tR\tdataLabel\x12\x1d\n\nsidecar_id\x18\r \x01(\tR\tsidecarId\x12\x1f\n\x03\x61ws\x18\x0e \x01(\x0b\x32\r.admin.v1.AWSR\x03\x61ws\x12\x30\n\x07\x63olumns\x18\x0f \x03(\x0b\x32\x16.admin.v1.ColumnPolicyR\x07\x63olumns\x12\x17\n\x07user_id\x18\x10 \x01(\tR\x06userId\x12\x1e\n\x0b\x65nd_user_id\x18\x11 \x01(\tR\tendUserId\x12\x30\n\tdatastore\x18\x12 \x01(\x0b\x32\x12.admin.v1.ResourceR\tdatastore\"~\n\x08Resource\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1e\n\ntechnology\x18\x03 \x01(\tR\ntechnology\x12\x1a\n\x08hostname\x18\x04 \x01(\tR\x08hostname\x12\x12\n\x04port\x18\x05 \x01(\x05R\x04port\"\x8b\x05\n\x0c\x43olumnPolicy\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x12,\n\x12parent_column_path\x18\x02 \x01(\tR\x10parentColumnPath\x12,\n\x12parent_column_type\x18\x03 \x01(\tR\x10parentColumnType\x12&\n\x0fparent_is_array\x18\x04 \x01(\x08R\rparentIsArray\x12!\n\x0cparent_index\x18\x05 \x01(\x05R\x0bparentIndex\x12(\n\x10parent_data_type\x18\x06 \x01(\tR\x0eparentDataType\x12\x1d\n\nsub_column\x18\x07 \x01(\x08R\tsubColumn\x12\x1b\n\tdata_type\x18\x08 \x01(\tR\x08\x64\x61taType\x12\x12\n\x04name\x18\t \x01(\tR\x04name\x12\x12\n\x04path\x18\n \x01(\tR\x04path\x12\x12\n\x04tags\x18\x0b \x03(\tR\x04tags\x12\x1d\n\ndata_label\x18\x0c \x01(\tR\tdataLabel\x12*\n\x05value\x18\r \x01(\x0b\x32\x14.google.protobuf.AnyR\x05value\x12Q\n\x0frow_level_usage\x18\x0e \x03(\x0b\x32).admin.v1.ColumnPolicy.RowLevelUsageEntryR\rrowLevelUsage\x12\x1f\n\x0b\x61rray_index\x18\x0f \x01(\x05R\narrayIndex\x12\x1b\n\tjson_path\x18\x10 \x01(\tR\x08jsonPath\x1a@\n\x12RowLevelUsageEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x03R\x05value:\x02\x38\x01\"C\n\nAWSAccount\x12\x1d\n\naccount_id\x18\x01 \x01(\tR\taccountId\x12\x16\n\x06region\x18\x02 \x01(\tR\x06region\")\n\x06\x41WSEC2\x12\x1f\n\x0binstance_id\x18\x01 \x01(\tR\ninstanceId\"\x8e\x01\n\x06\x41WSECS\x12!\n\x0c\x63luster_name\x18\x01 \x01(\tR\x0b\x63lusterName\x12!\n\x0cservice_name\x18\x02 \x01(\tR\x0bserviceName\x12\x17\n\x07task_id\x18\x03 \x01(\tR\x06taskId\x12%\n\x0e\x63ontainer_name\x18\x04 \x01(\tR\rcontainerName\"}\n\x03\x41WS\x12.\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x14.admin.v1.AWSAccountR\x07\x61\x63\x63ount\x12\"\n\x03\x65\x63\x32\x18\x02 \x01(\x0b\x32\x10.admin.v1.AWSEC2R\x03\x65\x63\x32\x12\"\n\x03\x65\x63s\x18\x03 \x01(\x0b\x32\x10.admin.v1.AWSECSR\x03\x65\x63s\"H\n\x16\x44ryRunPoliciesResponse\x12.\n\x07results\x18\x01 \x03(\x0e\x32\x14.admin.v1.PolicyTypeR\x07results\"\xed\x02\n\x13\x43reatePolicyRequest\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x1b\n\x04\x63ode\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\x12\x46\n\x0cnotification\x18\x04 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x05 \x03(\tR\x06owners\x12\x42\n\x0bsource_type\x18\x06 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x16\n\x06\x61\x63tive\x18\x07 \x01(\x08R\x06\x61\x63tive\x12\x35\n\x16termination_protection\x18\x08 \x01(\x08R\x15terminationProtection\"\xa6\x03\n\x15\x43reatePolicyV2Request\x12\x1b\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x1b\n\x04\x63ode\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04\x63ode\x12\x46\n\x0cnotification\x18\x04 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x05 \x03(\tR\x06owners\x12\x42\n\x0bsource_type\x18\x06 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x16\n\x06\x61\x63tive\x18\x07 \x01(\x08R\x06\x61\x63tive\x12\x35\n\x06status\x18\x08 \x01(\tB\x1d\xfa\x42\x1ar\x18R\x05\x64raftR\x07\x64ry-runR\x06\x61\x63tiveR\x06status\x12\x35\n\x16termination_protection\x18\t \x01(\x08R\x15terminationProtection\"I\n\x14\x43reatePolicyResponse\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x06policy\"M\n\x16\x43reatePolicyV2Response\x12\x33\n\x06policy\x18\x01 \x01(\x0b\x32\x1b.admin.v1.types.v1.PolicyV2R\x06policy\"\xfd\x02\n\x13UpdatePolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x42\n\x0bsource_type\x18\x02 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x1b\n\x04name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x12\n\x04\x63ode\x18\x05 \x01(\tR\x04\x63ode\x12\x46\n\x0cnotification\x18\x06 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x07 \x03(\tR\x06owners\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\x12\x35\n\x16termination_protection\x18\t \x01(\x08R\x15terminationProtection\"\xb6\x03\n\x15UpdatePolicyV2Request\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x42\n\x0bsource_type\x18\x02 \x01(\tB!\xfa\x42\x1er\x1cR\x07\x63onsoleR\tterraformR\x06githubR\nsourceType\x12\x1b\n\x04name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x12\n\x04\x63ode\x18\x05 \x01(\tR\x04\x63ode\x12\x46\n\x0cnotification\x18\x06 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x07 \x03(\tR\x06owners\x12\x16\n\x06\x61\x63tive\x18\x08 \x01(\x08R\x06\x61\x63tive\x12\x35\n\x06status\x18\t \x01(\tB\x1d\xfa\x42\x1ar\x18R\x05\x64raftR\x07\x64ry-runR\x06\x61\x63tiveR\x06status\x12\x35\n\x16termination_protection\x18\n \x01(\x08R\x15terminationProtection\"\x16\n\x14UpdatePolicyResponse\"\x18\n\x16UpdatePolicyV2Response\"/\n\x10GetPolicyRequest\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\"1\n\x12GetPolicyV2Request\x12\x1b\n\tpolicy_id\x18\x01 \x01(\tR\x08policyId\"F\n\x11GetPolicyResponse\x12\x31\n\x06policy\x18\x01 \x01(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x06policy\"J\n\x13GetPolicyV2Response\x12\x33\n\x06policy\x18\x01 \x01(\x0b\x32\x1b.admin.v1.types.v1.PolicyV2R\x06policy\"X\n\x12GetPoliciesRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor\x12\x14\n\x05order\x18\x03 \x01(\tR\x05order\"\x92\x01\n\x13GetPoliciesResponse\x12\x35\n\x08policies\x18\x01 \x03(\x0b\x32\x19.admin.v1.types.v1.PolicyR\x08policies\x12\x44\n\rlist_metadata\x18\x02 \x01(\x0b\x32\x1f.admin.v1.types.v1.ListMetadataR\x0clistMetadata\"\xeb\x01\n\x1d\x43reateSuspensionPolicyRequest\x12$\n\tpolicy_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08policyId\x12(\n\x0bidentity_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nidentityId\x12\x37\n\ridentity_type\x18\x03 \x01(\tB\x12\xfa\x42\x0fr\rR\x05groupR\x04userR\x0cidentityType\x12\x41\n\texpire_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02@\x01R\x08\x65xpireAt\"0\n\x1e\x43reateSuspensionPolicyResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"5\n\x1aGetSuspensionPolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"\x82\x02\n\x1bGetSuspensionPolicyResponse\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12$\n\tpolicy_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08policyId\x12(\n\x0bidentity_id\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nidentityId\x12\x37\n\ridentity_type\x18\x04 \x01(\tB\x12\xfa\x42\x0fr\rR\x05groupR\x04userR\x0cidentityType\x12\x41\n\texpire_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xfa\x42\x05\xb2\x01\x02\x08\x01R\x08\x65xpireAt\"8\n\x1d\x44\x65leteSuspensionPolicyRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\" \n\x1e\x44\x65leteSuspensionPolicyResponse*\x85\x01\n\x0ePolicyRuleType\x12 \n\x1cPOLICY_RULE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18POLICY_RULE_TYPE_SESSION\x10\x01\x12\x18\n\x14POLICY_RULE_TYPE_PRE\x10\x02\x12\x19\n\x15POLICY_RULE_TYPE_POST\x10\x03*\xb8\x01\n\nPolicyType\x12\x1b\n\x17POLICY_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11POLICY_TYPE_ALLOW\x10\x01\x12\x15\n\x11POLICY_TYPE_BLOCK\x10\x02\x12\x17\n\x13POLICY_TYPE_REWRITE\x10\x03\x12\x17\n\x13POLICY_TYPE_ENCRYPT\x10\x04\x12\x17\n\x13POLICY_TYPE_DECRYPT\x10\x05\x12\x14\n\x10POLICY_TYPE_MASK\x10\x06\x32\x8d\n\n\rPolicyService\x12L\n\x0bGetPolicies\x12\x1c.admin.v1.GetPoliciesRequest\x1a\x1d.admin.v1.GetPoliciesResponse\"\x00\x12\x46\n\tGetPolicy\x12\x1a.admin.v1.GetPolicyRequest\x1a\x1b.admin.v1.GetPolicyResponse\"\x00\x12L\n\x0bGetPolicyV2\x12\x1c.admin.v1.GetPolicyV2Request\x1a\x1d.admin.v1.GetPolicyV2Response\"\x00\x12O\n\x0c\x43reatePolicy\x12\x1d.admin.v1.CreatePolicyRequest\x1a\x1e.admin.v1.CreatePolicyResponse\"\x00\x12U\n\x0e\x43reatePolicyV2\x12\x1f.admin.v1.CreatePolicyV2Request\x1a .admin.v1.CreatePolicyV2Response\"\x00\x12O\n\x0cUpdatePolicy\x12\x1d.admin.v1.UpdatePolicyRequest\x1a\x1e.admin.v1.UpdatePolicyResponse\"\x00\x12U\n\x0eUpdatePolicyV2\x12\x1f.admin.v1.UpdatePolicyV2Request\x1a .admin.v1.UpdatePolicyV2Response\"\x00\x12O\n\x0c\x44\x65letePolicy\x12\x1d.admin.v1.DeletePolicyRequest\x1a\x1e.admin.v1.DeletePolicyResponse\"\x00\x12U\n\x0e\x44ryRunPolicies\x12\x1f.admin.v1.DryRunPoliciesRequest\x1a .admin.v1.DryRunPoliciesResponse\"\x00\x12m\n\x16\x45valuatePolicyValidity\x12\'.admin.v1.EvaluatePolicyValidityRequest\x1a(.admin.v1.EvaluatePolicyValidityResponse\"\x00\x12m\n\x16\x43reatePolicySuggestion\x12\'.admin.v1.CreatePolicySuggestionRequest\x1a(.admin.v1.CreatePolicySuggestionResponse\"\x00\x12m\n\x16\x43reateSuspensionPolicy\x12\'.admin.v1.CreateSuspensionPolicyRequest\x1a(.admin.v1.CreateSuspensionPolicyResponse\"\x00\x12\x64\n\x13GetSuspensionPolicy\x12$.admin.v1.GetSuspensionPolicyRequest\x1a%.admin.v1.GetSuspensionPolicyResponse\"\x00\x12m\n\x16\x44\x65leteSuspensionPolicy\x12\'.admin.v1.DeleteSuspensionPolicyRequest\x1a(.admin.v1.DeleteSuspensionPolicyResponse\"\x00\x42\xa3\x01\n\x0c\x63om.admin.v1B\rPoliciesProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.policies_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\rPoliciesProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_CREATEPOLICYSUGGESTIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPOLICYSUGGESTIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYSUGGESTIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPOLICYSUGGESTIONREQUEST'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEPOLICYREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEPOLICYREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_EVALUATEPOLICYVALIDITYREQUEST'].fields_by_name['code']._loaded_options = None
  _globals['_EVALUATEPOLICYVALIDITYREQUEST'].fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_COLUMNPOLICY_ROWLEVELUSAGEENTRY']._loaded_options = None
  _globals['_COLUMNPOLICY_ROWLEVELUSAGEENTRY']._serialized_options = b'8\001'
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['code']._loaded_options = None
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['notification']._loaded_options = None
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['source_type']._loaded_options = None
  _globals['_CREATEPOLICYREQUEST'].fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['code']._loaded_options = None
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['code']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['notification']._loaded_options = None
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['source_type']._loaded_options = None
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_CREATEPOLICYV2REQUEST'].fields_by_name['status']._serialized_options = b'\372B\032r\030R\005draftR\007dry-runR\006active'
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['source_type']._loaded_options = None
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['notification']._loaded_options = None
  _globals['_UPDATEPOLICYREQUEST'].fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['source_type']._loaded_options = None
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['source_type']._serialized_options = b'\372B\036r\034R\007consoleR\tterraformR\006github'
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['notification']._loaded_options = None
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['status']._loaded_options = None
  _globals['_UPDATEPOLICYV2REQUEST'].fields_by_name['status']._serialized_options = b'\372B\032r\030R\005draftR\007dry-runR\006active'
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['policy_id']._loaded_options = None
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['policy_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['identity_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['identity_type']._loaded_options = None
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['identity_type']._serialized_options = b'\372B\017r\rR\005groupR\004user'
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['expire_at']._loaded_options = None
  _globals['_CREATESUSPENSIONPOLICYREQUEST'].fields_by_name['expire_at']._serialized_options = b'\372B\005\262\001\002@\001'
  _globals['_GETSUSPENSIONPOLICYREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETSUSPENSIONPOLICYREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['id']._loaded_options = None
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['policy_id']._loaded_options = None
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['policy_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['identity_id']._loaded_options = None
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['identity_id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['identity_type']._loaded_options = None
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['identity_type']._serialized_options = b'\372B\017r\rR\005groupR\004user'
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['expire_at']._loaded_options = None
  _globals['_GETSUSPENSIONPOLICYRESPONSE'].fields_by_name['expire_at']._serialized_options = b'\372B\005\262\001\002\010\001'
  _globals['_DELETESUSPENSIONPOLICYREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETESUSPENSIONPOLICYREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICYRULETYPE']._serialized_start=5538
  _globals['_POLICYRULETYPE']._serialized_end=5671
  _globals['_POLICYTYPE']._serialized_start=5674
  _globals['_POLICYTYPE']._serialized_end=5858
  _globals['_CREATEPOLICYSUGGESTIONREQUEST']._serialized_start=196
  _globals['_CREATEPOLICYSUGGESTIONREQUEST']._serialized_end=299
  _globals['_CREATEPOLICYSUGGESTIONRESPONSE']._serialized_start=301
  _globals['_CREATEPOLICYSUGGESTIONRESPONSE']._serialized_end=365
  _globals['_DELETEPOLICYREQUEST']._serialized_start=367
  _globals['_DELETEPOLICYREQUEST']._serialized_end=413
  _globals['_DELETEPOLICYRESPONSE']._serialized_start=415
  _globals['_DELETEPOLICYRESPONSE']._serialized_end=437
  _globals['_EVALUATEPOLICYVALIDITYREQUEST']._serialized_start=439
  _globals['_EVALUATEPOLICYVALIDITYREQUEST']._serialized_end=499
  _globals['_EVALUATEPOLICYVALIDITYRESPONSE']._serialized_start=501
  _globals['_EVALUATEPOLICYVALIDITYRESPONSE']._serialized_end=595
  _globals['_DRYRUNPOLICIESREQUEST']._serialized_start=598
  _globals['_DRYRUNPOLICIESREQUEST']._serialized_end=1290
  _globals['_RESOURCE']._serialized_start=1292
  _globals['_RESOURCE']._serialized_end=1418
  _globals['_COLUMNPOLICY']._serialized_start=1421
  _globals['_COLUMNPOLICY']._serialized_end=2072
  _globals['_COLUMNPOLICY_ROWLEVELUSAGEENTRY']._serialized_start=2008
  _globals['_COLUMNPOLICY_ROWLEVELUSAGEENTRY']._serialized_end=2072
  _globals['_AWSACCOUNT']._serialized_start=2074
  _globals['_AWSACCOUNT']._serialized_end=2141
  _globals['_AWSEC2']._serialized_start=2143
  _globals['_AWSEC2']._serialized_end=2184
  _globals['_AWSECS']._serialized_start=2187
  _globals['_AWSECS']._serialized_end=2329
  _globals['_AWS']._serialized_start=2331
  _globals['_AWS']._serialized_end=2456
  _globals['_DRYRUNPOLICIESRESPONSE']._serialized_start=2458
  _globals['_DRYRUNPOLICIESRESPONSE']._serialized_end=2530
  _globals['_CREATEPOLICYREQUEST']._serialized_start=2533
  _globals['_CREATEPOLICYREQUEST']._serialized_end=2898
  _globals['_CREATEPOLICYV2REQUEST']._serialized_start=2901
  _globals['_CREATEPOLICYV2REQUEST']._serialized_end=3323
  _globals['_CREATEPOLICYRESPONSE']._serialized_start=3325
  _globals['_CREATEPOLICYRESPONSE']._serialized_end=3398
  _globals['_CREATEPOLICYV2RESPONSE']._serialized_start=3400
  _globals['_CREATEPOLICYV2RESPONSE']._serialized_end=3477
  _globals['_UPDATEPOLICYREQUEST']._serialized_start=3480
  _globals['_UPDATEPOLICYREQUEST']._serialized_end=3861
  _globals['_UPDATEPOLICYV2REQUEST']._serialized_start=3864
  _globals['_UPDATEPOLICYV2REQUEST']._serialized_end=4302
  _globals['_UPDATEPOLICYRESPONSE']._serialized_start=4304
  _globals['_UPDATEPOLICYRESPONSE']._serialized_end=4326
  _globals['_UPDATEPOLICYV2RESPONSE']._serialized_start=4328
  _globals['_UPDATEPOLICYV2RESPONSE']._serialized_end=4352
  _globals['_GETPOLICYREQUEST']._serialized_start=4354
  _globals['_GETPOLICYREQUEST']._serialized_end=4401
  _globals['_GETPOLICYV2REQUEST']._serialized_start=4403
  _globals['_GETPOLICYV2REQUEST']._serialized_end=4452
  _globals['_GETPOLICYRESPONSE']._serialized_start=4454
  _globals['_GETPOLICYRESPONSE']._serialized_end=4524
  _globals['_GETPOLICYV2RESPONSE']._serialized_start=4526
  _globals['_GETPOLICYV2RESPONSE']._serialized_end=4600
  _globals['_GETPOLICIESREQUEST']._serialized_start=4602
  _globals['_GETPOLICIESREQUEST']._serialized_end=4690
  _globals['_GETPOLICIESRESPONSE']._serialized_start=4693
  _globals['_GETPOLICIESRESPONSE']._serialized_end=4839
  _globals['_CREATESUSPENSIONPOLICYREQUEST']._serialized_start=4842
  _globals['_CREATESUSPENSIONPOLICYREQUEST']._serialized_end=5077
  _globals['_CREATESUSPENSIONPOLICYRESPONSE']._serialized_start=5079
  _globals['_CREATESUSPENSIONPOLICYRESPONSE']._serialized_end=5127
  _globals['_GETSUSPENSIONPOLICYREQUEST']._serialized_start=5129
  _globals['_GETSUSPENSIONPOLICYREQUEST']._serialized_end=5182
  _globals['_GETSUSPENSIONPOLICYRESPONSE']._serialized_start=5185
  _globals['_GETSUSPENSIONPOLICYRESPONSE']._serialized_end=5443
  _globals['_DELETESUSPENSIONPOLICYREQUEST']._serialized_start=5445
  _globals['_DELETESUSPENSIONPOLICYREQUEST']._serialized_end=5501
  _globals['_DELETESUSPENSIONPOLICYRESPONSE']._serialized_start=5503
  _globals['_DELETESUSPENSIONPOLICYRESPONSE']._serialized_end=5535
  _globals['_POLICYSERVICE']._serialized_start=5861
  _globals['_POLICYSERVICE']._serialized_end=7154
# @@protoc_insertion_point(module_scope)
