# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_external_api.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_external_api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'admin/v1/integration_external_api.proto\x12\x08\x61\x64min.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"\x9d\x01\n\x04\x41uth\x12(\n\x04type\x18\x01 \x01(\tB\x14\xfa\x42\x11r\x0fR\x05\x62\x61sicR\x06oauth2R\x04type\x12*\n\x05\x62\x61sic\x18\x02 \x01(\x0b\x32\x14.admin.v1.Auth.BasicR\x05\x62\x61sic\x1a?\n\x05\x42\x61sic\x12\x1a\n\x08username\x18\x01 \x01(\tR\x08username\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\"\xad\x01\n#CreateExternalApiIntegrationRequest\x12*\n\x04type\x18\x01 \x01(\tB\x16\xfa\x42\x13r\x11R\x07zendeskR\x06\x63ustomR\x04type\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x19\n\x03url\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03url\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x0e.admin.v1.AuthR\x04\x61uth\"6\n$CreateExternalApiIntegrationResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xb6\x02\n\x0e\x41piIntegration\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12*\n\x04type\x18\x02 \x01(\tB\x16\xfa\x42\x13r\x11R\x07zendeskR\x06\x63ustomR\x04type\x12\x1b\n\x04name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12\x19\n\x03url\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03url\x12\x31\n\tauth_type\x18\x05 \x01(\tB\x14\xfa\x42\x11r\x0fR\x05\x62\x61sicR\x06oauth2R\x08\x61uthType\x12\x39\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\";\n GetExternalApiIntegrationRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"_\n!GetExternalApiIntegrationResponse\x12:\n\x0bintegration\x18\x01 \x01(\x0b\x32\x18.admin.v1.ApiIntegrationR\x0bintegration\">\n#DeleteExternalApiIntegrationRequest\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\"&\n$DeleteExternalApiIntegrationResponse\"#\n!GetExternalApiIntegrationsRequest\"b\n\"GetExternalApiIntegrationsResponse\x12<\n\x0cintegrations\x18\x01 \x03(\x0b\x32\x18.admin.v1.ApiIntegrationR\x0cintegrations2\x89\x04\n\x12\x45xternalApiService\x12\x7f\n\x1c\x43reateExternalApiIntegration\x12-.admin.v1.CreateExternalApiIntegrationRequest\x1a..admin.v1.CreateExternalApiIntegrationResponse\"\x00\x12v\n\x19GetExternalApiIntegration\x12*.admin.v1.GetExternalApiIntegrationRequest\x1a+.admin.v1.GetExternalApiIntegrationResponse\"\x00\x12\x7f\n\x1c\x44\x65leteExternalApiIntegration\x12-.admin.v1.DeleteExternalApiIntegrationRequest\x1a..admin.v1.DeleteExternalApiIntegrationResponse\"\x00\x12y\n\x1aGetExternalApiIntegrations\x12+.admin.v1.GetExternalApiIntegrationsRequest\x1a,.admin.v1.GetExternalApiIntegrationsResponse\"\x00\x42\xb1\x01\n\x0c\x63om.admin.v1B\x1bIntegrationExternalApiProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_external_api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\033IntegrationExternalApiProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_AUTH'].fields_by_name['type']._loaded_options = None
  _globals['_AUTH'].fields_by_name['type']._serialized_options = b'\372B\021r\017R\005basicR\006oauth2'
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['type']._loaded_options = None
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['type']._serialized_options = b'\372B\023r\021R\007zendeskR\006custom'
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['url']._loaded_options = None
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_APIINTEGRATION'].fields_by_name['id']._loaded_options = None
  _globals['_APIINTEGRATION'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_APIINTEGRATION'].fields_by_name['type']._loaded_options = None
  _globals['_APIINTEGRATION'].fields_by_name['type']._serialized_options = b'\372B\023r\021R\007zendeskR\006custom'
  _globals['_APIINTEGRATION'].fields_by_name['name']._loaded_options = None
  _globals['_APIINTEGRATION'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_APIINTEGRATION'].fields_by_name['url']._loaded_options = None
  _globals['_APIINTEGRATION'].fields_by_name['url']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_APIINTEGRATION'].fields_by_name['auth_type']._loaded_options = None
  _globals['_APIINTEGRATION'].fields_by_name['auth_type']._serialized_options = b'\372B\021r\017R\005basicR\006oauth2'
  _globals['_GETEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_GETEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_DELETEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_DELETEEXTERNALAPIINTEGRATIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_AUTH']._serialized_start=115
  _globals['_AUTH']._serialized_end=272
  _globals['_AUTH_BASIC']._serialized_start=209
  _globals['_AUTH_BASIC']._serialized_end=272
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST']._serialized_start=275
  _globals['_CREATEEXTERNALAPIINTEGRATIONREQUEST']._serialized_end=448
  _globals['_CREATEEXTERNALAPIINTEGRATIONRESPONSE']._serialized_start=450
  _globals['_CREATEEXTERNALAPIINTEGRATIONRESPONSE']._serialized_end=504
  _globals['_APIINTEGRATION']._serialized_start=507
  _globals['_APIINTEGRATION']._serialized_end=817
  _globals['_GETEXTERNALAPIINTEGRATIONREQUEST']._serialized_start=819
  _globals['_GETEXTERNALAPIINTEGRATIONREQUEST']._serialized_end=878
  _globals['_GETEXTERNALAPIINTEGRATIONRESPONSE']._serialized_start=880
  _globals['_GETEXTERNALAPIINTEGRATIONRESPONSE']._serialized_end=975
  _globals['_DELETEEXTERNALAPIINTEGRATIONREQUEST']._serialized_start=977
  _globals['_DELETEEXTERNALAPIINTEGRATIONREQUEST']._serialized_end=1039
  _globals['_DELETEEXTERNALAPIINTEGRATIONRESPONSE']._serialized_start=1041
  _globals['_DELETEEXTERNALAPIINTEGRATIONRESPONSE']._serialized_end=1079
  _globals['_GETEXTERNALAPIINTEGRATIONSREQUEST']._serialized_start=1081
  _globals['_GETEXTERNALAPIINTEGRATIONSREQUEST']._serialized_end=1116
  _globals['_GETEXTERNALAPIINTEGRATIONSRESPONSE']._serialized_start=1118
  _globals['_GETEXTERNALAPIINTEGRATIONSRESPONSE']._serialized_end=1216
  _globals['_EXTERNALAPISERVICE']._serialized_start=1219
  _globals['_EXTERNALAPISERVICE']._serialized_end=1740
# @@protoc_insertion_point(module_scope)
