# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import cord_pb2 as admin_dot_v1_dot_cord__pb2


class CordServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetClientAuthToken = channel.unary_unary(
                '/admin.v1.CordService/GetClientAuthToken',
                request_serializer=admin_dot_v1_dot_cord__pb2.GetClientAuthTokenRequest.SerializeToString,
                response_deserializer=admin_dot_v1_dot_cord__pb2.GetClientAuthTokenResponse.FromString,
                _registered_method=True)


class CordServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetClientAuthToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CordServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetClientAuthToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClientAuthToken,
                    request_deserializer=admin_dot_v1_dot_cord__pb2.GetClientAuthTokenRequest.FromString,
                    response_serializer=admin_dot_v1_dot_cord__pb2.GetClientAuthTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'admin.v1.CordService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('admin.v1.CordService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CordService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetClientAuthToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/admin.v1.CordService/GetClientAuthToken',
            admin_dot_v1_dot_cord__pb2.GetClientAuthTokenRequest.SerializeToString,
            admin_dot_v1_dot_cord__pb2.GetClientAuthTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
