# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/integration_code_repository.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/integration_code_repository.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .types.v1 import coderepo_pb2 as admin_dot_v1_dot_types_dot_v1_dot_coderepo__pb2
from .types.v1 import github_repository_pb2 as admin_dot_v1_dot_types_dot_v1_dot_github__repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*admin/v1/integration_code_repository.proto\x12\x08\x61\x64min.v1\x1a admin/v1/types/v1/coderepo.proto\x1a)admin/v1/types/v1/github_repository.proto\"+\n\x19\x44\x65leteCodeRepoByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x1c\n\x1a\x44\x65leteCodeRepoByIdResponse\"1\n\x1f\x43\x61ncelDeleteCodeRepoByIdRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\"\n CancelDeleteCodeRepoByIdResponse\"_\n\x1c\x43onnectCodeRepositoryRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\x12\x12\n\x04\x63ode\x18\x03 \x01(\tR\x04\x63ode\"B\n\x1d\x43onnectCodeRepositoryResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\"D\n\x15GetAccessTokenRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x12\n\x04type\x18\x02 \x01(\tR\x04type\";\n\x16GetAccessTokenResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\"C\n(GetGithubRepositoriesFromAuthUserRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"t\n)GetGithubRepositoriesFromAuthUserResponse\x12G\n\x0crepositories\x18\x01 \x03(\x0b\x32#.admin.v1.types.v1.GithubRepositoryR\x0crepositories\"4\n\x19GetUserAccessTokenRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\"?\n\x1aGetUserAccessTokenResponse\x12!\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\tR\x0b\x61\x63\x63\x65ssToken\"\x15\n\x13GetCodeReposRequest\"W\n\x14GetCodeReposResponse\x12?\n\x0crepositories\x18\x01 \x03(\x0b\x32\x1b.admin.v1.types.v1.CodeRepoR\x0crepositories\"T\n\x15\x43reateCodeRepoRequest\x12;\n\nrepository\x18\x01 \x01(\x0b\x32\x1b.admin.v1.types.v1.CodeRepoR\nrepository\"\x18\n\x16\x43reateCodeRepoResponse2\xbe\x06\n\x15\x43odeRepositoryService\x12_\n\x12\x44\x65leteCodeRepoById\x12#.admin.v1.DeleteCodeRepoByIdRequest\x1a$.admin.v1.DeleteCodeRepoByIdResponse\x12q\n\x18\x43\x61ncelDeleteCodeRepoById\x12).admin.v1.CancelDeleteCodeRepoByIdRequest\x1a*.admin.v1.CancelDeleteCodeRepoByIdResponse\x12h\n\x15\x43onnectCodeRepository\x12&.admin.v1.ConnectCodeRepositoryRequest\x1a\'.admin.v1.ConnectCodeRepositoryResponse\x12S\n\x0eGetAccessToken\x12\x1f.admin.v1.GetAccessTokenRequest\x1a .admin.v1.GetAccessTokenResponse\x12\x8c\x01\n!GetGithubRepositoriesFromAuthUser\x12\x32.admin.v1.GetGithubRepositoriesFromAuthUserRequest\x1a\x33.admin.v1.GetGithubRepositoriesFromAuthUserResponse\x12_\n\x12GetUserAccessToken\x12#.admin.v1.GetUserAccessTokenRequest\x1a$.admin.v1.GetUserAccessTokenResponse\x12M\n\x0cGetCodeRepos\x12\x1d.admin.v1.GetCodeReposRequest\x1a\x1e.admin.v1.GetCodeReposResponse\x12S\n\x0e\x43reateCodeRepo\x12\x1f.admin.v1.CreateCodeRepoRequest\x1a .admin.v1.CreateCodeRepoResponseB\xb4\x01\n\x0c\x63om.admin.v1B\x1eIntegrationCodeRepositoryProtoP\x01ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\xa2\x02\x03\x41XX\xaa\x02\x08\x41\x64min.V1\xca\x02\x08\x41\x64min\\V1\xe2\x02\x14\x41\x64min\\V1\\GPBMetadata\xea\x02\tAdmin::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.integration_code_repository_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\014com.admin.v1B\036IntegrationCodeRepositoryProtoP\001ZCgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1;adminv1\242\002\003AXX\252\002\010Admin.V1\312\002\010Admin\\V1\342\002\024Admin\\V1\\GPBMetadata\352\002\tAdmin::V1'
  _globals['_DELETECODEREPOBYIDREQUEST']._serialized_start=133
  _globals['_DELETECODEREPOBYIDREQUEST']._serialized_end=176
  _globals['_DELETECODEREPOBYIDRESPONSE']._serialized_start=178
  _globals['_DELETECODEREPOBYIDRESPONSE']._serialized_end=206
  _globals['_CANCELDELETECODEREPOBYIDREQUEST']._serialized_start=208
  _globals['_CANCELDELETECODEREPOBYIDREQUEST']._serialized_end=257
  _globals['_CANCELDELETECODEREPOBYIDRESPONSE']._serialized_start=259
  _globals['_CANCELDELETECODEREPOBYIDRESPONSE']._serialized_end=293
  _globals['_CONNECTCODEREPOSITORYREQUEST']._serialized_start=295
  _globals['_CONNECTCODEREPOSITORYREQUEST']._serialized_end=390
  _globals['_CONNECTCODEREPOSITORYRESPONSE']._serialized_start=392
  _globals['_CONNECTCODEREPOSITORYRESPONSE']._serialized_end=458
  _globals['_GETACCESSTOKENREQUEST']._serialized_start=460
  _globals['_GETACCESSTOKENREQUEST']._serialized_end=528
  _globals['_GETACCESSTOKENRESPONSE']._serialized_start=530
  _globals['_GETACCESSTOKENRESPONSE']._serialized_end=589
  _globals['_GETGITHUBREPOSITORIESFROMAUTHUSERREQUEST']._serialized_start=591
  _globals['_GETGITHUBREPOSITORIESFROMAUTHUSERREQUEST']._serialized_end=658
  _globals['_GETGITHUBREPOSITORIESFROMAUTHUSERRESPONSE']._serialized_start=660
  _globals['_GETGITHUBREPOSITORIESFROMAUTHUSERRESPONSE']._serialized_end=776
  _globals['_GETUSERACCESSTOKENREQUEST']._serialized_start=778
  _globals['_GETUSERACCESSTOKENREQUEST']._serialized_end=830
  _globals['_GETUSERACCESSTOKENRESPONSE']._serialized_start=832
  _globals['_GETUSERACCESSTOKENRESPONSE']._serialized_end=895
  _globals['_GETCODEREPOSREQUEST']._serialized_start=897
  _globals['_GETCODEREPOSREQUEST']._serialized_end=918
  _globals['_GETCODEREPOSRESPONSE']._serialized_start=920
  _globals['_GETCODEREPOSRESPONSE']._serialized_end=1007
  _globals['_CREATECODEREPOREQUEST']._serialized_start=1009
  _globals['_CREATECODEREPOREQUEST']._serialized_end=1093
  _globals['_CREATECODEREPORESPONSE']._serialized_start=1095
  _globals['_CREATECODEREPORESPONSE']._serialized_end=1119
  _globals['_CODEREPOSITORYSERVICE']._serialized_start=1122
  _globals['_CODEREPOSITORYSERVICE']._serialized_end=1952
# @@protoc_insertion_point(module_scope)
