# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: admin/v1/types/v1/policy.proto
# Protobuf Python Version: 5.27.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    3,
    '',
    'admin/v1/types/v1/policy.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .....validate.v1 import validate_pb2 as validate_dot_v1_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61\x64min/v1/types/v1/policy.proto\x12\x11\x61\x64min.v1.types.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1avalidate/v1/validate.proto\"\xd5\x03\n\x06Policy\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x12\n\x04\x63ode\x18\x04 \x01(\tR\x04\x63ode\x12\x10\n\x03\x61st\x18\x05 \x01(\tR\x03\x61st\x12\x46\n\x0cnotification\x18\x06 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x07 \x03(\tR\x06owners\x12\x1f\n\x0bsource_type\x18\x08 \x01(\tR\nsourceType\x12\x39\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x16\n\x06\x61\x63tive\x18\x0b \x01(\x08R\x06\x61\x63tive\x12\x35\n\x16termination_protection\x18\x0c \x01(\x08R\x15terminationProtection\"\x8e\x04\n\x08PolicyV2\x12\x17\n\x02id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x02id\x12\x1b\n\x04name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04name\x12)\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0b\x64\x65scription\x12\x12\n\x04\x63ode\x18\x04 \x01(\tR\x04\x63ode\x12\x10\n\x03\x61st\x18\x05 \x01(\tR\x03\x61st\x12\x46\n\x0cnotification\x18\x06 \x01(\tB\"\xfa\x42\x1fr\x1dR\x04noneR\x08\x63onsumerR\x06ownersR\x03\x61llR\x0cnotification\x12\x16\n\x06owners\x18\x07 \x03(\tR\x06owners\x12\x1f\n\x0bsource_type\x18\x08 \x01(\tR\nsourceType\x12\x39\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x16\n\x06\x61\x63tive\x18\x0b \x01(\x08R\x06\x61\x63tive\x12\x35\n\x06status\x18\x0c \x01(\tB\x1d\xfa\x42\x1ar\x18R\x05\x64raftR\x07\x64ry-runR\x06\x61\x63tiveR\x06status\x12\x35\n\x16termination_protection\x18\r \x01(\x08R\x15terminationProtectionB\xd9\x01\n\x15\x63om.admin.v1.types.v1B\x0bPolicyProtoP\x01ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\xa2\x02\x03\x41VT\xaa\x02\x11\x41\x64min.V1.Types.V1\xca\x02\x11\x41\x64min\\V1\\Types\\V1\xe2\x02\x1d\x41\x64min\\V1\\Types\\V1\\GPBMetadata\xea\x02\x14\x41\x64min::V1::Types::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'admin.v1.types.v1.policy_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.admin.v1.types.v1B\013PolicyProtoP\001ZLgithub.com/formalco/monorepo/backend/apis/core/gen/admin/v1/types/v1;typesv1\242\002\003AVT\252\002\021Admin.V1.Types.V1\312\002\021Admin\\V1\\Types\\V1\342\002\035Admin\\V1\\Types\\V1\\GPBMetadata\352\002\024Admin::V1::Types::V1'
  _globals['_POLICY'].fields_by_name['id']._loaded_options = None
  _globals['_POLICY'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICY'].fields_by_name['name']._loaded_options = None
  _globals['_POLICY'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICY'].fields_by_name['description']._loaded_options = None
  _globals['_POLICY'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICY'].fields_by_name['notification']._loaded_options = None
  _globals['_POLICY'].fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_POLICYV2'].fields_by_name['id']._loaded_options = None
  _globals['_POLICYV2'].fields_by_name['id']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICYV2'].fields_by_name['name']._loaded_options = None
  _globals['_POLICYV2'].fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICYV2'].fields_by_name['description']._loaded_options = None
  _globals['_POLICYV2'].fields_by_name['description']._serialized_options = b'\372B\004r\002\020\001'
  _globals['_POLICYV2'].fields_by_name['notification']._loaded_options = None
  _globals['_POLICYV2'].fields_by_name['notification']._serialized_options = b'\372B\037r\035R\004noneR\010consumerR\006ownersR\003all'
  _globals['_POLICYV2'].fields_by_name['status']._loaded_options = None
  _globals['_POLICYV2'].fields_by_name['status']._serialized_options = b'\372B\032r\030R\005draftR\007dry-runR\006active'
  _globals['_POLICY']._serialized_start=115
  _globals['_POLICY']._serialized_end=584
  _globals['_POLICYV2']._serialized_start=587
  _globals['_POLICYV2']._serialized_end=1113
# @@protoc_insertion_point(module_scope)
